@@ -19,19 +19,25 @@ from sklearn.dummy import DummyClassifier, DummyRegressor
 import matplotlib.pyplot as plt
 
 import ads
-from ads.common.utils import ml_task_types, wrap_lines, \
-    is_documentation_mode, is_notebook, print_user_message
+from ads.common.utils import (
+    ml_task_types,
+    wrap_lines,
+    is_documentation_mode,
+    is_notebook,
+)
 from ads.dataset.label_encoder import DataFrameLabelEncoder
 
 from IPython.core.display import display, HTML
 
-from ads.common import utils
+from ads.common import logger, utils
+
 
 class AutoMLProvider(ABC):
-    '''
+    """
     Abstract Base Class defining the structure of an AutoML solution. The solution needs to
     implement train() and get_transformer_pipeline().
-    '''
+    """
+
     def __init__(self):
         self.X_train = None
         self.y_train = None
@@ -43,8 +49,17 @@ class AutoMLProvider(ABC):
         self.transformer_pipeline = None
         self.est = None
 
-    def setup(self, X_train, y_train, ml_task_type, X_valid=None, y_valid=None, class_names=None, client=None):
-        '''
+    def setup(
+        self,
+        X_train,
+        y_train,
+        ml_task_type,
+        X_valid=None,
+        y_valid=None,
+        class_names=None,
+        client=None,
+    ):
+        """
         Setup arguments to the AutoML instance.
 
         Parameters
@@ -63,7 +78,7 @@ class AutoMLProvider(ABC):
             Unique values in y_train
         client : object
             Dask client instance for distributed execution
-        '''
+        """
         self.X_train = X_train
         self.y_train = y_train
         self.X_valid = X_valid
@@ -118,11 +133,12 @@ class AutoMLProvider(ABC):
         """
         pass
 
+
 class BaselineModel(object):
-    '''
+    """
     A BaselineModel object that supports fit/predict/predict_proba/transform
     interface. Labels (y) are encoded using DataFrameLabelEncoder.
-    '''
+    """
 
     def __init__(self, est):
         self.est = est
@@ -215,8 +231,8 @@ class BaselineModel(object):
         set_config()
         return str(self.est)[:-2]
 
-class BaselineAutoMLProvider(AutoMLProvider):
 
+class BaselineAutoMLProvider(AutoMLProvider):
     def get_transformer_pipeline(self):
         """
         Returns a list of transformers representing the transformations done on data before model prediction.
@@ -232,7 +248,7 @@ class BaselineAutoMLProvider(AutoMLProvider):
         return [("automl_preprocessing", AutoMLPreprocessingTransformer(msg))]
 
     def __init__(self, est):
-        '''
+        """
         Generates a baseline model using the Zero Rule algorithm by default. For a classification
         predictive modeling problem where a categorical value is predicted, the Zero
         Rule algorithm predicts the class value that has the most observations in the training dataset.
@@ -242,7 +258,7 @@ class BaselineAutoMLProvider(AutoMLProvider):
         est : BaselineModel
             An estimator that supports the fit/predict/predict_proba interface.
             By default, DummyClassifier/DummyRegressor are used as estimators
-        '''
+        """
         super(BaselineAutoMLProvider, self).__init__()
         self.est = est
 
@@ -253,16 +269,14 @@ class BaselineAutoMLProvider(AutoMLProvider):
     def train(self, **kwargs):
         self.est = self.decide_estimator(**kwargs)
         if self.est is None:
-            raise ValueError("Baseline model for (%s) is not supported" % self.ml_task_type)
+            raise ValueError(
+                "Baseline model for (%s) is not supported" % self.ml_task_type
+            )
         try:
             self.est.fit(self.X_train, self.y_train)
         except Exception as e:
-            warning_message = "The following baseline estimator failed to fit properly and is not possible to evaluate: " + str(self.est) + " Exception: " + str(e)
-            utils.print_user_message(
-                warning_message,
-                display_type="warning",
-                title="AutoML"
-            )
+            warning_message = f"The baseline estimator failed to fit the data. It could not evaluate {self.est} and gave the exception {e}."
+            logger.warning(warning_message)
 
     def decide_estimator(self, **kwargs):
         """
@@ -278,15 +292,19 @@ class BaselineAutoMLProvider(AutoMLProvider):
         else:
             if self.ml_task_type == ml_task_types.REGRESSION:
                 return BaselineModel(DummyRegressor())
-            elif self.ml_task_type in [ml_task_types.BINARY_CLASSIFICATION, ml_task_types.MULTI_CLASS_CLASSIFICATION,
-                                       ml_task_types.BINARY_TEXT_CLASSIFICATION,
-                                       ml_task_types.MULTI_CLASS_TEXT_CLASSIFICATION]:
+            elif self.ml_task_type in [
+                ml_task_types.BINARY_CLASSIFICATION,
+                ml_task_types.MULTI_CLASS_CLASSIFICATION,
+                ml_task_types.BINARY_TEXT_CLASSIFICATION,
+                ml_task_types.MULTI_CLASS_TEXT_CLASSIFICATION,
+            ]:
                 return BaselineModel(DummyClassifier())
 
+
 # An installation of oracle labs automl is required only for this class
 class OracleAutoMLProvider(AutoMLProvider, ABC):
     def __init__(self, n_jobs=-1, loglevel=None, logger_override=None):
-        '''
+        """
         The Oracle AutoML Provider automatically provides a tuned ML pipeline that best models the given a training
         dataset and a prediction task at hand.
 
@@ -298,12 +316,12 @@ class OracleAutoMLProvider(AutoMLProvider, ABC):
         loglevel : int
             The verbosity of output for Oracle AutoML. Can be specified using the Python logging module
             (https://docs.python.org/3/library/logging.html#logging-levels).
-        '''
+        """
         try:
-            self.automl = __import__('automl')
-            self.cpuinfo = __import__('cpuinfo')
+            self.automl = __import__("automl")
+            self.cpuinfo = __import__("cpuinfo")
         except ModuleNotFoundError as e:
-            print_user_message(["automl", "ads[labs]"], display_type="module")
+            utils._log_missing_module("automl", "ads[labs]")
             raise e
         super(OracleAutoMLProvider, self).__init__()
         if loglevel is None:
@@ -314,12 +332,18 @@ class OracleAutoMLProvider(AutoMLProvider, ABC):
             logr = logger_override
         else:
             logr = logging.getLogger(__name__)
-
-        from ads.environment import ml_runtime
-        if not logger_override:
-            self.automl.init(engine="dask",engine_opts={'dask_scheduler':ml_runtime.compute_accelerator()}, loglevel=loglevel)
+        if "AMD" in self.cpuinfo.get_cpu_info().get("brand", "UNKNOWN-BRAND"):
+            # Disable intra-model parallelism for LightGBM and XGBoost libraries
+            # which seem to be unstable currently on AMD shapes
+            self.automl.init(
+                engine="local",
+                engine_opts={"n_jobs": n_jobs, "model_n_jobs": 1},
+                loglevel=loglevel,
+            )
         else:
-            self.automl.init(engine="dask",engine_opts={'dask_scheduler':ml_runtime.compute_accelerator()},logger=logr)
+            self.automl.init(
+                engine="local", engine_opts={"n_jobs": n_jobs}, logger=logr
+            )
 
     def __repr__(self):
         super(OracleAutoMLProvider, self).__repr__()
@@ -335,9 +359,10 @@ class OracleAutoMLProvider(AutoMLProvider, ABC):
         -------
         transformers_list : list of transformers implementing fit and transform
         """
-        if hasattr(self.est, 'text') and not self.est.text:
-            msg1 = wrap_lines(self.est.selected_features_names_,
-                              heading="Select features:")
+        if hasattr(self.est, "text") and not self.est.text:
+            msg1 = wrap_lines(
+                self.est.selected_features_names_, heading="Select features:"
+            )
             return [("automl_feature_selection", AutoMLFeatureSelection(msg1))]
         else:
             msg = "Apply Tfidf Vectorization\n"
@@ -346,13 +371,18 @@ class OracleAutoMLProvider(AutoMLProvider, ABC):
             return [("automl_preprocessing", AutoMLPreprocessingTransformer(msg))]
 
     def selected_model_name(self):
-        '''
+        """
         Return the name of the selected model by AutoML.
-        '''
+        """
         return self.est.selected_model_
 
-    def print_summary(self, max_rows=None, sort_column='Mean Validation Score', ranking_table_only=False):
-        '''
+    def print_summary(
+        self,
+        max_rows=None,
+        sort_column="Mean Validation Score",
+        ranking_table_only=False,
+    ):
+        """
         Prints a summary of the Oracle AutoML Pipeline in the last train() call.
 
         Parameters
@@ -366,51 +396,96 @@ class OracleAutoMLProvider(AutoMLProvider, ABC):
             Table to be displayed. Pass in False to display the complete table.
             Pass in True to display the ranking table only.
 
-        '''
-        if is_documentation_mode() and is_notebook(): # pragma: no cover
-            print_user_message("Training complete ({0:.2f} seconds)".format(time.time()-self.train_start_time), title=None)
+        """
+        if is_notebook():  # pragma: no cover
+            logger.info(
+                f"Training time was ({(time.time() - self.train_start_time):.2f} seconds.)"
+            )
+
+            if len(self.est.tuning_trials_) == 0 or len(self.est.train_shape_) == 0:
+                logger.error(
+                    "Unfortunately, there were no trials found, so we cannot visualize it."
+                )
+                return
+
             info = [
-                ['Training Dataset size', self.X_train.shape],
-                ['Validation Dataset size', self.X_valid.shape if self.X_valid is not None else None],
-                ['CV', self.est.num_cv_folds_],
-                ['Target variable', self.y_train.name],
-                ['Optimization Metric', self.est.inferred_score_metric],
-                ['Initial number of Features', self.est.train_shape_[1]],
-                ['Selected number of Features', len(self.est.selected_features_names_)],
-                ['Selected Features', self.est.selected_features_names_],
-                ['Selected Algorithm', self.est.selected_model_],
-                ['End-to-end Elapsed Time (seconds)', self.train_end_time - self.train_start_time],
-                ['Selected Hyperparameters', self.est.selected_model_params_],
-                ['Mean Validation Score', self.est.tuning_trials_[0][3]],
-                ['AutoML n_jobs', self.est.n_jobs_],
-                ['AutoML version', self.automl.__version__],
-                ['Python version', sys.version]
+                ["Training Dataset size", self.X_train.shape],
+                [
+                    "Validation Dataset size",
+                    self.X_valid.shape if self.X_valid is not None else None,
+                ],
+                ["CV", self.est.num_cv_folds_],
+                ["Target variable", self.y_train.name],
+                ["Optimization Metric", self.est.inferred_score_metric],
+                ["Initial number of Features", self.est.train_shape_[1]],
+                ["Selected number of Features", len(self.est.selected_features_names_)],
+                ["Selected Features", self.est.selected_features_names_],
+                ["Selected Algorithm", self.est.selected_model_],
+                [
+                    "End-to-end Elapsed Time (seconds)",
+                    self.train_end_time - self.train_start_time,
+                ],
+                ["Selected Hyperparameters", self.est.selected_model_params_],
+                ["Mean Validation Score", self.est.tuning_trials_[0][3]],
+                ["AutoML n_jobs", self.est.n_jobs_],
+                ["AutoML version", self.automl.__version__],
+                ["Python version", sys.version],
             ]
             info_df = pd.DataFrame(info)
 
             # Remove the selected model and its params from the trials since it already shows up in the summary table
-            all_trials_ = self.est.model_selection_trials_ + self.est.adaptive_sampling_trials_ + \
-                self.est.feature_selection_trials_ + self.est.tuning_trials_[1:]
-            col_names = ['Algorithm', '#Samples', '#Features', 'Mean Validation Score', \
-                'Hyperparameters', 'All Validation Scores', 'CPU Time']
+            all_trials_ = (
+                self.est.model_selection_trials_
+                + self.est.adaptive_sampling_trials_
+                + self.est.feature_selection_trials_
+                + self.est.tuning_trials_[1:]
+            )
+            col_names = [
+                "Algorithm",
+                "#Samples",
+                "#Features",
+                "Mean Validation Score",
+                "Hyperparameters",
+                "All Validation Scores",
+                "CPU Time",
+                "Memory Usage",
+            ]
             if ranking_table_only:
-                dropped_cols = ['#Samples', '#Features', 'All Validation Scores', 'CPU Time']
+                dropped_cols = [
+                    "#Samples",
+                    "#Features",
+                    "All Validation Scores",
+                    "CPU Time",
+                ]
             else:
-                dropped_cols = 'All Validation Scores'
-            summary_df = pd.DataFrame(all_trials_, columns=col_names).drop(dropped_cols, axis=1)
+                dropped_cols = "All Validation Scores"
+            summary_df = pd.DataFrame(all_trials_, columns=col_names).drop(
+                dropped_cols, axis=1
+            )
             sorted_summary_df = summary_df.sort_values(sort_column, ascending=False)
             # Add a rank column at the front
-            sorted_summary_df.insert(0, 'Rank based on Performance', np.arange(2, len(sorted_summary_df)+2))
+            sorted_summary_df.insert(
+                0, "Rank based on Performance", np.arange(2, len(sorted_summary_df) + 2)
+            )
 
-            with pd.option_context('display.max_colwidth', 1000, 'display.width', None, 'display.precision', 4):
+            with pd.option_context(
+                "display.max_colwidth",
+                1000,
+                "display.width",
+                None,
+                "display.precision",
+                4,
+            ):
                 display(HTML(info_df.to_html(index=False, header=False)))
                 if max_rows is None:
                     display(HTML(sorted_summary_df.to_html(index=False)))
                 else:
-                    display(HTML(sorted_summary_df.to_html(index=False, max_rows=max_rows)))
+                    display(
+                        HTML(sorted_summary_df.to_html(index=False, max_rows=max_rows))
+                    )
 
     def train(self, **kwargs):
-        '''
+        """
         Train the Oracle AutoML Pipeline. This looks at the training data, and
         identifies the best set of features, the best algorithm and the best
         set of hyperparameters for this data. A model is then generated, trained
@@ -444,33 +519,39 @@ class OracleAutoMLProvider(AutoMLProvider, ABC):
         Returns
         -------
         self : object
-        '''
-
+        """
 
         """Adding this part to give the correct error for situations when dataset > 10000 rows and user tries SVC or KNN"""
         if len(self.X_train) > 10000:
-            if 'model_list' in kwargs:
+            if "model_list" in kwargs:
                 bad_model_list = ["SVC", "KNeighborsClassifier"]
-                for model in kwargs['model_list']:
+                for model in kwargs["model_list"]:
                     for item in bad_model_list:
                         if item in model:
-                            raise ValueError("SVC, KNeighborsClassifier are disabled for datasets with > 10K samples")
+                            raise ValueError(
+                                "SVC, KNeighborsClassifier are disabled for datasets with > 10K samples"
+                            )
 
         self.train_start_time = time.time()
-        if 'time_budget' in kwargs:
-            self.time_budget = kwargs.pop('time_budget')
+        if "time_budget" in kwargs:
+            self.time_budget = kwargs.pop("time_budget")
         else:
-            self.time_budget = 0 # unlimited
+            self.time_budget = 0  # unlimited
         self.est = self._decide_estimator(**kwargs)
         with warnings.catch_warnings():
             warnings.simplefilter("ignore")
-            self.est.fit(self.X_train, self.y_train, X_valid=self.X_valid,
-                y_valid=self.y_valid, time_budget=self.time_budget)
+            self.est.fit(
+                self.X_train,
+                self.y_train,
+                X_valid=self.X_valid,
+                y_valid=self.y_valid,
+                time_budget=self.time_budget,
+            )
         self.train_end_time = time.time()
         self.print_summary(max_rows=10)
 
-    def print_trials(self, max_rows=None, sort_column='Mean Validation Score'):
-        '''
+    def print_trials(self, max_rows=None, sort_column="Mean Validation Score"):
+        """
         Prints all trials executed by the Oracle AutoML Pipeline in the last train() call.
 
         Parameters
@@ -481,49 +562,63 @@ class OracleAutoMLProvider(AutoMLProvider, ABC):
             Column to sort results by. Must be one of ['Algorithm', '#Samples', '#Features', 'Mean Validation Score',
             'Hyperparameters', 'All Validation Scores', 'CPU Time']
 
-        '''
+        """
         self.est.print_trials(max_rows=max_rows, sort_column=sort_column)
 
     def _decide_estimator(self, **kwargs):
-        '''
+        """
         Decide arguments to the Oracle AutoML pipeline based on user provided
         arguments
-        '''
+        """
         est = None
         score_metric = None
         # Explicity define the default AutoML metrics
-        if self.ml_task_type == ml_task_types.BINARY_CLASSIFICATION or \
-            self.ml_task_type == ml_task_types.BINARY_TEXT_CLASSIFICATION:
-            test_model_list = ['LogisticRegression']
-        elif self.ml_task_type == ml_task_types.MULTI_CLASS_CLASSIFICATION or \
-            self.ml_task_type == ml_task_types.MULTI_CLASS_TEXT_CLASSIFICATION:
-            test_model_list = ['LogisticRegression']
+        if (
+            self.ml_task_type == ml_task_types.BINARY_CLASSIFICATION
+            or self.ml_task_type == ml_task_types.BINARY_TEXT_CLASSIFICATION
+        ):
+            test_model_list = ["LogisticRegression"]
+        elif (
+            self.ml_task_type == ml_task_types.MULTI_CLASS_CLASSIFICATION
+            or self.ml_task_type == ml_task_types.MULTI_CLASS_TEXT_CLASSIFICATION
+        ):
+            test_model_list = ["LogisticRegression"]
         elif self.ml_task_type == ml_task_types.REGRESSION:
-            test_model_list = ['LinearRegression']
+            test_model_list = ["LinearRegression"]
         else:
             raise ValueError("AutoML for (%s) is not supported" % self.ml_task_type)
 
         # Respect the user provided scoring metric if given
-        if 'score_metric' in kwargs:
-            score_metric = kwargs.pop('score_metric')
+        if "score_metric" in kwargs:
+            score_metric = kwargs.pop("score_metric")
 
         #
         # ***FOR TESTING PURPOSE ONLY***
         #
         # Ignore model_list for test mode
-        if ads.test_mode: # pragma: no cover
-            if 'model_list' in kwargs:
-                _ = kwargs.pop('model_list')
-            kwargs['model_list'] = test_model_list        
+        if ads.test_mode:  # pragma: no cover
+            if "model_list" in kwargs:
+                _ = kwargs.pop("model_list")
+            kwargs["model_list"] = test_model_list
 
-        if self.ml_task_type == ml_task_types.BINARY_CLASSIFICATION or \
-            self.ml_task_type == ml_task_types.MULTI_CLASS_CLASSIFICATION:
-            est = self.automl.Pipeline(task='classification', score_metric=score_metric, **kwargs)
-        elif self.ml_task_type == ml_task_types.BINARY_TEXT_CLASSIFICATION or \
-            self.ml_task_type == ml_task_types.MULTI_CLASS_TEXT_CLASSIFICATION:
-            est = self.automl.Pipeline(task='classification', text=True, score_metric=score_metric, **kwargs)
+        if (
+            self.ml_task_type == ml_task_types.BINARY_CLASSIFICATION
+            or self.ml_task_type == ml_task_types.MULTI_CLASS_CLASSIFICATION
+        ):
+            est = self.automl.Pipeline(
+                task="classification", score_metric=score_metric, **kwargs
+            )
+        elif (
+            self.ml_task_type == ml_task_types.BINARY_TEXT_CLASSIFICATION
+            or self.ml_task_type == ml_task_types.MULTI_CLASS_TEXT_CLASSIFICATION
+        ):
+            est = self.automl.Pipeline(
+                task="classification", text=True, score_metric=score_metric, **kwargs
+            )
         elif self.ml_task_type == ml_task_types.REGRESSION:
-            est = self.automl.Pipeline(task='regression', score_metric=score_metric, **kwargs)
+            est = self.automl.Pipeline(
+                task="regression", score_metric=score_metric, **kwargs
+            )
         else:
             raise ValueError("AutoML for (%s) is not supported" % self.ml_task_type)
         return est
@@ -538,7 +633,6 @@ class OracleAutoMLProvider(AutoMLProvider, ABC):
             score_label = self.est.inferred_score_metric
         return score_label
 
-
     def visualize_algorithm_selection_trials(self, ylabel=None):
         """
         Plot the scores predicted by Algorithm Selection for each algorithm. The
@@ -556,34 +650,52 @@ class OracleAutoMLProvider(AutoMLProvider, ABC):
             ylabel = self.selected_score_label().capitalize()
         trials = self.est.model_selection_trials_
         if not len(trials):
-            print_user_message("Unfortunately, there were no trials found for Algorithm Selection, \
-            so we cannot visualize it.", display_type="error")
+            _log_visualize_no_trials("algorithm selection")
             return
         fig, ax = plt.subplots(1, figsize=(6, 3))
         colors = []
         y_error = []
         mean_scores, models, cvscores = [], [], []
-        for (algorithm, samples, features, mean_score, hyperparameters, all_scores, runtime) in trials:
+        for (
+            algorithm,
+            samples,
+            features,
+            mean_score,
+            hyperparameters,
+            all_scores,
+            runtime,
+            x,
+        ) in trials:
             mean_scores.append(mean_score)
             models.append(algorithm)
             cvscores.append(all_scores)
-        mean_scores_ser = pd.Series(mean_scores, index=models).sort_values(ascending=False)
+        mean_scores_ser = pd.Series(mean_scores, index=models).sort_values(
+            ascending=False
+        )
         scores_ser = pd.Series(cvscores, index=models)
         ax.set_title("Algorithm Selection Trials")
         ax.set_ylabel(ylabel)
-        ax.set_xlabel('Algorithm')
+        ax.set_xlabel("Algorithm")
         for f in mean_scores_ser.keys():
             se = sem(scores_ser[f], ddof=1)
             y_error.append(se)
-            if f == '{}_AS'.format(self.est.selected_model_):
-                colors.append('orange')
+            if f == "{}_AS".format(self.est.selected_model_):
+                colors.append("orange")
             elif mean_scores_ser[f] >= mean_scores_ser.mean():
-                colors.append('teal')
+                colors.append("teal")
             else:
-                colors.append('turquoise')
-        mean_scores_ser.plot.bar(ax=ax, color=colors, edgecolor='black', zorder=1)
-        ax.errorbar(x=mean_scores_ser.index.values, y=mean_scores_ser.values, yerr=y_error, fmt='none', capsize=4, color='black', zorder=0)
-        ax.axhline(y=mean_scores_ser.mean(), color='black', linewidth=0.5)
+                colors.append("turquoise")
+        mean_scores_ser.plot.bar(ax=ax, color=colors, edgecolor="black", zorder=1)
+        ax.errorbar(
+            x=mean_scores_ser.index.values,
+            y=mean_scores_ser.values,
+            yerr=y_error,
+            fmt="none",
+            capsize=4,
+            color="black",
+            zorder=0,
+        )
+        ax.axhline(y=mean_scores_ser.mean(), color="black", linewidth=0.5)
         ax.autoscale_view()
         plt.show()
 
@@ -593,19 +705,42 @@ class OracleAutoMLProvider(AutoMLProvider, ABC):
         """
         trials = self.est.adaptive_sampling_trials_
         if len(trials) == 0:
-            print_user_message("Unfortunately, there were no trials found for Adaptive Sampling, \
-            so we cannot visualize it.", display_type="error")
+            _log_visualize_no_trials("adaptive sampling")
             return
         fig, ax = plt.subplots(1, figsize=(6, 3))
         ax.set_title("Adaptive Sampling ({})".format(trials[0][0]))
-        ax.set_xlabel('Dataset sample size')
+        ax.set_xlabel("Dataset sample size")
         ax.set_ylabel(r"Predicted model score")
-        scores = [mean_score for (algorithm, samples, features, mean_score, hyperparameters, all_scores, runtime) in trials]
-        n_samples = [samples for (algorithm, samples, features, mean_score, hyperparameters, all_scores, runtime) in trials]
+        scores = [
+            mean_score
+            for (
+                algorithm,
+                samples,
+                features,
+                mean_score,
+                hyperparameters,
+                all_scores,
+                runtime,
+                x,
+            ) in trials
+        ]
+        n_samples = [
+            samples
+            for (
+                algorithm,
+                samples,
+                features,
+                mean_score,
+                hyperparameters,
+                all_scores,
+                runtime,
+                x,
+            ) in trials
+        ]
         y_margin = 0.10 * (max(scores) - min(scores))
-        ax.grid(color='g', linestyle='-', linewidth=0.1)
+        ax.grid(color="g", linestyle="-", linewidth=0.1)
         ax.set_ylim(min(scores) - y_margin, max(scores) + y_margin)
-        ax.plot(n_samples, scores, 'k:', marker="s", color='teal', markersize=3)
+        ax.plot(n_samples, scores, "k:", marker="s", color="teal", markersize=3)
         plt.show()
 
     def visualize_feature_selection_trials(self, ylabel=None):
@@ -623,20 +758,45 @@ class OracleAutoMLProvider(AutoMLProvider, ABC):
             ylabel = self.selected_score_label().capitalize()
         trials = self.est.feature_selection_trials_
         if len(trials) == 0:
-            print_user_message("Unfortunately, there were no trials found for Feature Selection, \
-            so we cannot visualize it.", display_type="error")
+            _log_visualize_no_trials("feature selection")
             return
         fig, ax = plt.subplots(1, figsize=(6, 3))
         ax.set_title("Feature Selection Trials")
         ax.set_xlabel("Number of Features")
         ax.set_ylabel(ylabel)
-        scores = [mean_score for (algorithm, samples, features, mean_score, hyperparameters, all_scores, runtime) in trials]
-        n_features = [features for (algorithm, samples, features, mean_score, hyperparameters, all_scores, runtime) in trials]
+        scores = [
+            mean_score
+            for (
+                algorithm,
+                samples,
+                features,
+                mean_score,
+                hyperparameters,
+                all_scores,
+                runtime,
+                x,
+            ) in trials
+        ]
+        n_features = [
+            features
+            for (
+                algorithm,
+                samples,
+                features,
+                mean_score,
+                hyperparameters,
+                all_scores,
+                runtime,
+                x,
+            ) in trials
+        ]
         y_margin = 0.10 * (max(scores) - min(scores))
-        ax.grid(color='g', linestyle='-', linewidth=0.1)
+        ax.grid(color="g", linestyle="-", linewidth=0.1)
         ax.set_ylim(min(scores) - y_margin, max(scores) + y_margin)
-        ax.plot(n_features, scores, 'k:', marker="s", color='teal', markersize=3)
-        ax.axvline(x=len(self.est.selected_features_names_), color='orange', linewidth=2.0)
+        ax.plot(n_features, scores, "k:", marker="s", color="teal", markersize=3)
+        ax.axvline(
+            x=len(self.est.selected_features_names_), color="orange", linewidth=2.0
+        )
         plt.show()
 
     def visualize_tuning_trials(self, ylabel=None):
@@ -654,11 +814,21 @@ class OracleAutoMLProvider(AutoMLProvider, ABC):
             ylabel = self.selected_score_label().capitalize()
         # scores in trials are sorted decreasingly.
         # reversed(trails) : let the scores sort in increasing order from left to right.
-        scores = [mean_score for (algorithm, samples, features, mean_score, hyperparameters, all_scores, runtime) in
-                  reversed(self.est.tuning_trials_) if mean_score and not np.isnan(mean_score)]
+        scores = [
+            mean_score
+            for (
+                algorithm,
+                samples,
+                features,
+                mean_score,
+                hyperparameters,
+                all_scores,
+                runtime,
+                x,
+            ) in reversed(self.est.tuning_trials_)
+            if mean_score and not np.isnan(mean_score)
+        ]
         if not len(scores) > 1:
-            print_user_message(f"Insufficient tuning trials ({len(scores)}r) to visualize in the time budget \
-                             of {self.time_budget} seconds.", display_type="error")
             raise RuntimeError("Insufficient tuning trials.")
         else:
             fig, ax = plt.subplots(1, figsize=(6, 3))
@@ -666,12 +836,20 @@ class OracleAutoMLProvider(AutoMLProvider, ABC):
             ax.set_xlabel("Iteration $n$")
             ax.set_ylabel(ylabel)
             y_margin = 0.10 * (max(scores) - min(scores))
-            ax.grid(color='g', linestyle='-', linewidth=0.1)
+            ax.grid(color="g", linestyle="-", linewidth=0.1)
             ax.set_ylim(min(scores) - y_margin, max(scores) + y_margin)
-            ax.plot(range(1, len(scores) + 1), scores, 'k:', marker="s", color='teal', markersize=3)
+            ax.plot(
+                range(1, len(scores) + 1),
+                scores,
+                "k:",
+                marker="s",
+                color="teal",
+                markersize=3,
+            )
             plt.show()
 
-class AutoMLPreprocessingTransformer(object): # pragma: no cover
+
+class AutoMLPreprocessingTransformer(object):  # pragma: no cover
     def __init__(self, msg):
         self.msg = msg
 
@@ -707,11 +885,16 @@ class AutoMLPreprocessingTransformer(object): # pragma: no cover
         """
         return X
 
+    def _log_visualize_no_trials(target):
+        logger.error(
+            f"There are no trials. Therefore, the {target} cannot be visualized."
+        )
+
     def __repr__(self):
         return self.msg
 
 
-class AutoMLFeatureSelection(object): # pragma: no cover
+class AutoMLFeatureSelection(object):  # pragma: no cover
     def __init__(self, msg):
         self.msg = msg
 
