@@ -31,17 +31,35 @@ from dask import dataframe as dd
 from ads.common import utils
 from ads.common.utils import is_same_class
 from ads.dataset import logger
-from ads.dataset.classification_dataset import BinaryClassificationDataset, MultiClassClassificationDataset, \
-    BinaryTextClassificationDataset, MultiClassTextClassificationDataset
+from ads.dataset.classification_dataset import (
+    BinaryClassificationDataset,
+    MultiClassClassificationDataset,
+    BinaryTextClassificationDataset,
+    MultiClassTextClassificationDataset,
+)
 from ads.dataset.dataset import ADSDataset
 from ads.dataset.forecasting_dataset import ForecastingDataset
-from ads.dataset.helper import get_feature_type, is_text_data, generate_sample, map_types, DatasetDefaults, \
-    ElaboratedPath, DatasetLoadException, _num_partitions_for_dataframe
+from ads.dataset.helper import (
+    get_feature_type,
+    is_text_data,
+    generate_sample,
+    map_types,
+    DatasetDefaults,
+    ElaboratedPath,
+    DatasetLoadException,
+    _num_partitions_for_dataframe,
+)
 from ads.dataset.regression_dataset import RegressionDataset
 from ads.environment import ml_runtime as runtime
 from ads.type_discovery.type_discovery_driver import TypeDiscoveryDriver
-from ads.type_discovery.typed_feature import ContinuousTypedFeature, DateTimeTypedFeature, CategoricalTypedFeature, \
-    OrdinalTypedFeature, GISTypedFeature, DocumentTypedFeature
+from ads.type_discovery.typed_feature import (
+    ContinuousTypedFeature,
+    DateTimeTypedFeature,
+    CategoricalTypedFeature,
+    OrdinalTypedFeature,
+    GISTypedFeature,
+    DocumentTypedFeature,
+)
 from ads.type_discovery.typed_feature import TypedFeature
 from typing import Callable, Tuple, Optional, Any
 from ocifs import OCIFileSystem
@@ -49,13 +67,26 @@ from ocifs import OCIFileSystem
 default_snapshots_dir = None
 default_storage_options = None
 
-class DatasetFactory:
 
+class DatasetFactory:
     @staticmethod
-    def open(source, target=None, format="infer", reader_fn: Callable = None, name: str = None, description="",
-             npartitions: int = None, type_discovery=True, html_table_index=None, column_names="infer",
-             sample_max_rows=10000, positive_class=None, transformer_pipeline=None, types={},
-             **kwargs):
+    def open(
+        source,
+        target=None,
+        format="infer",
+        reader_fn: Callable = None,
+        name: str = None,
+        description="",
+        npartitions: int = None,
+        type_discovery=True,
+        html_table_index=None,
+        column_names="infer",
+        sample_max_rows=10000,
+        positive_class=None,
+        transformer_pipeline=None,
+        types={},
+        **kwargs,
+    ):
         """
         Returns an object of ADSDataset or ADSDatasetWithTarget  read from the given path
 
@@ -125,9 +156,9 @@ class DatasetFactory:
         >>> ds = DatasetFactory.open("/path/to/data.csv", target="col_1", prefix="col_",  skiprows=1, \
                     encoding="ISO-8859-1")
 
-        >>> ds = DatasetFactory.open("oci://path/to/data.tsv", column_names=["col1", "col2", "col3"], header=0)
+        >>> ds = DatasetFactory.open("oci://bucket@namespace/path/to/data.tsv", column_names=["col1", "col2", "col3"], header=0)
 
-        >>> ds = DatasetFactory.open("oci://path/to/data.csv", storage_options={"config": "~/.oci/config",
+        >>> ds = DatasetFactory.open("oci://bucket@namespace/path/to/data.csv", storage_options={"config": "~/.oci/config",
                     "profile": "USER_2"}, delimiter = ';')
 
         >>> ds = DatasetFactory.open("/path/to/data.parquet", engine='pyarrow', types={"col1": "ordinal", \
@@ -138,11 +169,23 @@ class DatasetFactory:
         >>> ds = DatasetFactory.open("s3://path/to/data.json.gz", format="json", compression="gzip", orient="records")
         """
 
+        if (
+            "storage_options" not in kwargs
+            and type(source) is str
+            and len(source) > 6
+            and source[:6] == "oci://"
+        ):
+            kwargs["storage_options"] = {"config": {}}
+
         if isinstance(source, str) or isinstance(source, list):
             progress = utils.get_progress_bar(4)
             progress.update("Opening data")
             path = ElaboratedPath(source, format=format, **kwargs)
-            reader_fn = get_format_reader(path=path, **kwargs) if reader_fn is None else reader_fn
+            reader_fn = (
+                get_format_reader(path=path, **kwargs)
+                if reader_fn is None
+                else reader_fn
+            )
             df = load_dataset(path=path, reader_fn=reader_fn, **kwargs)
             name = path.name
         elif isinstance(source, pd.DataFrame) or isinstance(source, dd.DataFrame):
@@ -151,24 +194,44 @@ class DatasetFactory:
             df = source if isinstance(source, pd.DataFrame) else source.compute()
             name = "User Provided DataFrame" if name is None else name
         else:
-            raise TypeError(f"The Source type: {type(source)} is not supported for DatasetFactory.")
+            raise TypeError(
+                f"The Source type: {type(source)} is not supported for DatasetFactory."
+            )
         shape = df.shape
-        ddf = dd.from_pandas(df, npartitions=_num_partitions_for_dataframe(df) if npartitions is None else npartitions)
-        return DatasetFactory._build_dataset(ddf=ddf, shape=shape, target=target,
-                                             sample_max_rows=sample_max_rows, type_discovery=type_discovery,
-                                             types=types, positive_class=positive_class, name=name,
-                                             transformer_pipeline=transformer_pipeline, description=description,
-                                             progress=progress, **utils.inject_and_copy_kwargs(kwargs, **{
-                "html_table_index": html_table_index,
-                "column_names": column_names
-            }))
+        ddf = dd.from_pandas(
+            df,
+            npartitions=_num_partitions_for_dataframe(df)
+            if npartitions is None
+            else npartitions,
+        )
+        return DatasetFactory._build_dataset(
+            ddf=ddf,
+            shape=shape,
+            target=target,
+            sample_max_rows=sample_max_rows,
+            type_discovery=type_discovery,
+            types=types,
+            positive_class=positive_class,
+            name=name,
+            transformer_pipeline=transformer_pipeline,
+            description=description,
+            progress=progress,
+            **utils.inject_and_copy_kwargs(
+                kwargs,
+                **{"html_table_index": html_table_index, "column_names": column_names},
+            ),
+        )
 
     @staticmethod
-    def open_to_pandas(source: str, format: str = None, reader_fn: Callable = None, **kwargs) -> pd.DataFrame:
+    def open_to_pandas(
+        source: str, format: str = None, reader_fn: Callable = None, **kwargs
+    ) -> pd.DataFrame:
         path = ElaboratedPath(source, format=format, **kwargs)
-        reader_fn = get_format_reader(path=path, **kwargs) if reader_fn is None else reader_fn
+        reader_fn = (
+            get_format_reader(path=path, **kwargs) if reader_fn is None else reader_fn
+        )
         df = load_dataset(path=path, reader_fn=reader_fn, **kwargs)
-        return df 
+        return df
 
     @staticmethod
     def from_dataframe(df, target: str = None, npartitions: int = None, **kwargs):
@@ -221,8 +284,10 @@ class DatasetFactory:
         if snapshot_dir is None:
             snapshot_dir = default_snapshots_dir
             if snapshot_dir is None:
-                raise ValueError("Specify snapshot_dir or use DatasetFactory.set_default_storage() to set default \
-                                      storage options")
+                raise ValueError(
+                    "Specify snapshot_dir or use DatasetFactory.set_default_storage() to set default \
+                                      storage options"
+                )
             else:
                 logger.info("Using default snapshots dir %s" % snapshot_dir)
         if storage_options is None:
@@ -231,17 +296,23 @@ class DatasetFactory:
                 logger.info("Using default storage options")
             else:
                 storage_options = dict()
-        assert isinstance(storage_options, dict), "The storage options parameter must be a dictionary. You can set " \
-                                                  "this gloabally by calling DatasetFactory.set_default_storage(" \
-                                                  "storage_options={\'config\': \'location\'}). "
+        assert isinstance(storage_options, dict), (
+            "The storage options parameter must be a dictionary. You can set "
+            "this gloabally by calling DatasetFactory.set_default_storage("
+            "storage_options={'config': 'location'}). "
+        )
         url_options = infer_storage_options(snapshot_dir)
         protocol = url_options.pop("protocol", None)
 
-        fs = OCIFileSystem(config=storage_options.get('config', None))
-        kwargs.update({'refresh': True})
-        obj_list = [(k, v.get('timeCreated', mindate).strftime("%Y-%m-%d %H:%M:%S"))
-                    for k, v in fs.glob(os.path.join(snapshot_dir, name + "**"), detail=True, **kwargs).items() if
-                    v['type'] == 'file']
+        fs = OCIFileSystem(config=storage_options.get("config", None))
+        kwargs.update({"refresh": True})
+        obj_list = [
+            (k, v.get("timeCreated", mindate).strftime("%Y-%m-%d %H:%M:%S"))
+            for k, v in fs.glob(
+                os.path.join(snapshot_dir, name + "**"), detail=True, **kwargs
+            ).items()
+            if v["type"] == "file"
+        ]
 
         files = []
         for file, file_time in obj_list:
@@ -249,11 +320,11 @@ class DatasetFactory:
                 r1 = re.compile(r"/part\.[0-9]{1,6}\.parquet$")
                 parquet_part = r1.search(file)
                 if parquet_part is not None:
-                    parquet_filename = file[:parquet_part.start()]
+                    parquet_filename = file[: parquet_part.start()]
                 elif file.endswith("/_common_metadata"):
-                    parquet_filename = file[:-len("/_common_metadata")]
+                    parquet_filename = file[: -len("/_common_metadata")]
                 elif file.endswith("/_metadata"):
-                    parquet_filename = file[:-len("/_metadata")]
+                    parquet_filename = file[: -len("/_metadata")]
                 else:
                     parquet_filename = file
             else:
@@ -268,7 +339,13 @@ class DatasetFactory:
 
         # display in HTML format if sdk is run in notebook mode
         if utils.is_notebook():
-            display(HTML(list_df.style.set_table_attributes('class=table').hide_index().render()))
+            display(
+                HTML(
+                    list_df.style.set_table_attributes("class=table")
+                    .hide_index()
+                    .render()
+                )
+            )
         return list_df
 
     @staticmethod
@@ -298,32 +375,37 @@ class DatasetFactory:
             else:
                 storage = dict()
 
-        remote_files = fsspec.open_files(remote_path, mode='rb', name_function=lambda i: "", **storage)
+        remote_files = fsspec.open_files(
+            remote_path, mode="rb", name_function=lambda i: "", **storage
+        )
         if len(remote_files) < 1:
             raise FileNotFoundError(remote_path)
-        display_error, error_msg = DatasetFactory._download_files(remote_files=remote_files,
-                                                                  local_path=local_path,
-                                                                  overwrite=overwrite)
+        display_error, error_msg = DatasetFactory._download_files(
+            remote_files=remote_files, local_path=local_path, overwrite=overwrite
+        )
         if display_error:
-            utils.print_user_message("WARNING: " + error_msg, display_type='tip')
+            logger.error(error_msg)
         else:
-            utils.print_user_message(f"Successfully downloaded from remote dir/file: {remote_path} to local "
-                                     f"dir/file: {local_path}", display_type='tip')
+            logger.info(f"Download {remote_path} to {local_path}.")
 
     @staticmethod
     def _download_files(remote_files, local_path, overwrite=False):
         display_error, error_msg = False, ""
         for remote_file in remote_files:
-            bucket_idx = remote_file.path.find('/')
-            suffix = remote_file.path[bucket_idx + 1:]
+            bucket_idx = remote_file.path.find("/")
+            suffix = remote_file.path[bucket_idx + 1 :]
             try:
                 with remote_file as f1:
-                    local_filepath = os.path.join(local_path, suffix) if suffix else local_path
+                    local_filepath = (
+                        os.path.join(local_path, suffix) if suffix else local_path
+                    )
                     if os.path.exists(local_filepath) and not overwrite:
-                        raise FileExistsError(f"Trying to overwrite files in {local_filepath}. If you'd like to "
-                                              f"overwrite these files, please set force_overwrite to True.")
+                        raise FileExistsError(
+                            f"Trying to overwrite files in {local_filepath}. If you'd like to "
+                            f"overwrite these files, please set force_overwrite to True."
+                        )
                     os.makedirs(os.path.dirname(local_filepath), exist_ok=True)
-                    with open(local_filepath, 'wb') as f2:
+                    with open(local_filepath, "wb") as f2:
                         f2.write(f1.read())
             except oci.exceptions.ServiceError as e:
                 raise FileNotFoundError(f"Unable to open file: {remote_file.path}")
@@ -355,11 +437,18 @@ class DatasetFactory:
                     if os.path.abspath(subdir) == os.path.abspath(local_file_or_dir):
                         path = file
                     else:
-                        path = os.path.join(os.path.abspath(subdir).split("/", 2)[2], file)
-                    DatasetFactory._upload_file(os.path.join(subdir, file), os.path.join(remote_file_or_dir, path),
-                                                storage_options=storage_options)
+                        path = os.path.join(
+                            os.path.abspath(subdir).split("/", 2)[2], file
+                        )
+                    DatasetFactory._upload_file(
+                        os.path.join(subdir, file),
+                        os.path.join(remote_file_or_dir, path),
+                        storage_options=storage_options,
+                    )
         else:
-            DatasetFactory._upload_file(local_file_or_dir, remote_file_or_dir, storage_options=storage_options)
+            DatasetFactory._upload_file(
+                local_file_or_dir, remote_file_or_dir, storage_options=storage_options
+            )
 
     @staticmethod
     def set_default_storage(snapshots_dir=None, storage_options=None):
@@ -379,8 +468,10 @@ class DatasetFactory:
         default_snapshots_dir = snapshots_dir
         global default_storage_options
         if storage_options is not None:
-            assert isinstance(storage_options, dict), f"The storage options parameter must be a dictionary. Instead " \
-                                                      f"we got the type: {type(storage_options)} "
+            assert isinstance(storage_options, dict), (
+                f"The storage options parameter must be a dictionary. Instead "
+                f"we got the type: {type(storage_options)} "
+            )
         default_storage_options = storage_options
 
     @classmethod
@@ -388,8 +479,9 @@ class DatasetFactory:
         kwargs = {}
         if storage_options is not None:
             kwargs = {"storage_options": storage_options}
-        remote_file_handler = fsspec.open_files(remote_file + "*", mode='wb',
-                                                name_function=lambda i: "", **kwargs)[0]
+        remote_file_handler = fsspec.open_files(
+            remote_file + "*", mode="wb", name_function=lambda i: "", **kwargs
+        )[0]
         with remote_file_handler as f1:
             with open(local_file, "rb") as f2:
                 for line in f2:
@@ -397,7 +489,14 @@ class DatasetFactory:
         print("Uploaded %s to %s" % (local_file, remote_file))
 
     @classmethod
-    def _build_dataset(cls, ddf: dd.DataFrame, shape: Tuple[int, int], target: str = None, progress=None, **kwargs):
+    def _build_dataset(
+        cls,
+        ddf: dd.DataFrame,
+        shape: Tuple[int, int],
+        target: str = None,
+        progress=None,
+        **kwargs,
+    ):
         n = shape[0]
         if progress:
             progress.update("Generating data sample")
@@ -407,16 +506,18 @@ class DatasetFactory:
             n,
             DatasetDefaults.sampling_confidence_level,
             DatasetDefaults.sampling_confidence_interval,
-            **kwargs
+            **kwargs,
         )
 
         if target is None:
             if progress:
-                progress.update("Building dataset with no target")
+                progress.update("Building the dataset with no target.")
             result = ADSDataset(ddf=ddf, sampled_df=sampled_df, shape=shape, **kwargs)
             if progress:
                 progress.update("Done")
-            utils.print_user_message("Use <code>set_target()</code> to type the dataset for a particular learning task")
+            logger.info(
+                "Use `set_target()` to type the dataset for a particular learning task."
+            )
             return result
 
         if progress:
@@ -428,87 +529,173 @@ class DatasetFactory:
             discover_target_type = False
 
         # if type discovery is turned off, infer type from pandas dtype
-        target_type = DatasetFactory.infer_target_type(target, sampled_df[target], discover_target_type)
+        target_type = DatasetFactory.infer_target_type(
+            target, sampled_df[target], discover_target_type
+        )
 
-        result = DatasetFactory._get_dataset(ddf=ddf, sampled_df=sampled_df, target=target, target_type=target_type,
-                                             shape=shape, **kwargs)
+        result = DatasetFactory._get_dataset(
+            ddf=ddf,
+            sampled_df=sampled_df,
+            target=target,
+            target_type=target_type,
+            shape=shape,
+            **kwargs,
+        )
         if progress:
             progress.update("Done")
-        utils.print_user_message(
-            'Use <code>show_in_notebook()</code> to visualize the dataset.\nUse <code>suggest_recommendations('
-            ')</code> to view and apply recommendations for dataset optimization.')
+        logger.info(
+            "Use `suggest_recommendations()` to view and apply recommendations for dataset optimization."
+        )
         return result
 
     @classmethod
     def infer_target_type(cls, target, target_series, discover_target_type=True):
         # if type discovery is turned off, infer type from pandas dtype
         if discover_target_type:
-            target_type = TypeDiscoveryDriver().discover(target, target_series, is_target=True)
+            target_type = TypeDiscoveryDriver().discover(
+                target, target_series, is_target=True
+            )
         else:
             target_type = get_feature_type(target, target_series)
         return target_type
 
     @classmethod
-    def _get_dataset(cls, ddf: dd.DataFrame, sampled_df: pd.DataFrame, target: str, target_type: TypedFeature,
-                     shape: Tuple[int, int], positive_class=None, **init_kwargs):
+    def _get_dataset(
+        cls,
+        ddf: dd.DataFrame,
+        sampled_df: pd.DataFrame,
+        target: str,
+        target_type: TypedFeature,
+        shape: Tuple[int, int],
+        positive_class=None,
+        **init_kwargs,
+    ):
         if len(ddf[target].dropna()) == 0:
-            utils.print_user_message("We do not recommend using an empty column as the chosen target")
-            raise ValueError(f"We do not support using empty columns as the chosen target")
+            logger.warning(
+                "It is not recommended to use an empty column as the target variable."
+            )
+            raise ValueError(
+                f"We do not support using empty columns as the chosen target"
+            )
         if is_same_class(target_type, ContinuousTypedFeature):
-            return RegressionDataset(ddf=ddf, sampled_df=sampled_df, target=target, target_type=target_type,
-                                     shape=shape, **init_kwargs)
-        elif is_same_class(target_type, DateTimeTypedFeature) or ddf.index.dtype.name.startswith('datetime'):
-            return ForecastingDataset(ddf=ddf, sampled_df=sampled_df, target=target, target_type=target_type,
-                                      shape=shape, **init_kwargs)
+            return RegressionDataset(
+                ddf=ddf,
+                sampled_df=sampled_df,
+                target=target,
+                target_type=target_type,
+                shape=shape,
+                **init_kwargs,
+            )
+        elif is_same_class(
+            target_type, DateTimeTypedFeature
+        ) or ddf.index.dtype.name.startswith("datetime"):
+            return ForecastingDataset(
+                ddf=ddf,
+                sampled_df=sampled_df,
+                target=target,
+                target_type=target_type,
+                shape=shape,
+                **init_kwargs,
+            )
 
         # Adding ordinal typed feature, but ultimately we should rethink how we want to model this type
-        elif is_same_class(target_type, CategoricalTypedFeature) or is_same_class(target_type, OrdinalTypedFeature):
-            if target_type.meta_data['internal']['unique'] == 2:
+        elif is_same_class(target_type, CategoricalTypedFeature) or is_same_class(
+            target_type, OrdinalTypedFeature
+        ):
+            if target_type.meta_data["internal"]["unique"] == 2:
                 if is_text_data(sampled_df, target):
-                    return BinaryTextClassificationDataset(ddf=ddf, sampled_df=sampled_df, target=target, shape=shape,
-                                                           target_type=target_type, positive_class=positive_class,
-                                                           **init_kwargs)
+                    return BinaryTextClassificationDataset(
+                        ddf=ddf,
+                        sampled_df=sampled_df,
+                        target=target,
+                        shape=shape,
+                        target_type=target_type,
+                        positive_class=positive_class,
+                        **init_kwargs,
+                    )
 
-                return BinaryClassificationDataset(ddf=ddf, sampled_df=sampled_df, target=target, shape=shape,
-                                                   target_type=target_type, positive_class=positive_class,
-                                                   **init_kwargs)
+                return BinaryClassificationDataset(
+                    ddf=ddf,
+                    sampled_df=sampled_df,
+                    target=target,
+                    shape=shape,
+                    target_type=target_type,
+                    positive_class=positive_class,
+                    **init_kwargs,
+                )
             else:
                 if is_text_data(sampled_df, target):
-                    return MultiClassTextClassificationDataset(ddf=ddf, sampled_df=sampled_df, target=target,
-                                                               target_type=target_type, shape=shape, **init_kwargs)
-                return MultiClassClassificationDataset(ddf=ddf, sampled_df=sampled_df, target=target,
-                                                       target_type=target_type, shape=shape, **init_kwargs)
-        elif is_same_class(target, DocumentTypedFeature) or 'text' in target_type['type'] or 'text' in target:
-            utils.print_user_message("Consider using another column as the target")
-            raise ValueError(f"We do not recommend using {target} as the chosen target")
-        elif is_same_class(target_type, GISTypedFeature) or 'coord' in target_type['type'] or 'coord' in target:
-            utils.print_user_message("Consider using another column as the target")
-            raise ValueError(f"We do not recommend using {target} as the chosen target")
+                    return MultiClassTextClassificationDataset(
+                        ddf=ddf,
+                        sampled_df=sampled_df,
+                        target=target,
+                        target_type=target_type,
+                        shape=shape,
+                        **init_kwargs,
+                    )
+                return MultiClassClassificationDataset(
+                    ddf=ddf,
+                    sampled_df=sampled_df,
+                    target=target,
+                    target_type=target_type,
+                    shape=shape,
+                    **init_kwargs,
+                )
+        elif (
+            is_same_class(target, DocumentTypedFeature)
+            or "text" in target_type["type"]
+            or "text" in target
+        ):
+            raise ValueError(
+                f"The column {target} cannot be used as the target column."
+            )
+        elif (
+            is_same_class(target_type, GISTypedFeature)
+            or "coord" in target_type["type"]
+            or "coord" in target
+        ):
+            raise ValueError(
+                f"The column {target} cannot be used as the target column."
+            )
         # This is to catch constant columns that are boolean. Added as a fix for pd.isnull(), and datasets with a
         #   binary target, but only data on one instance
-        elif target_type['low_level_type'] == 'bool':
-            return BinaryClassificationDataset(ddf=ddf, sampled_df=sampled_df, target=target, shape=shape,
-                                               target_type=target_type, positive_class=positive_class, **init_kwargs)
-        raise ValueError(f"Unable to identify problem type. Please specify the data type of {target} using 'types'. "
-                         f"For example, types = {{{target}: 'category'}}")
+        elif target_type["low_level_type"] == "bool":
+            return BinaryClassificationDataset(
+                ddf=ddf,
+                sampled_df=sampled_df,
+                target=target,
+                shape=shape,
+                target_type=target_type,
+                positive_class=positive_class,
+                **init_kwargs,
+            )
+        raise ValueError(
+            f"Unable to identify problem type. Please specify the data type of {target} using 'types'. "
+            f"For example, types = {{{target}: 'category'}}"
+        )
 
 
 class CustomFormatReaders:
     @staticmethod
     def read_tsv(path: str, **kwargs) -> pd.DataFrame:
-        return pd.read_csv(path, **utils.inject_and_copy_kwargs(kwargs, **{'sep': '\t'}))
+        return pd.read_csv(
+            path, **utils.inject_and_copy_kwargs(kwargs, **{"sep": "\t"})
+        )
 
     @staticmethod
     def read_json(path: str, **kwargs) -> pd.DataFrame:
         try:
             return pd.read_json(path, **kwargs)
         except ValueError as e:
-            return pd.read_json(path, **utils.inject_and_copy_kwargs(kwargs, **{'lines': True}))
+            return pd.read_json(
+                path, **utils.inject_and_copy_kwargs(kwargs, **{"lines": True})
+            )
 
     @staticmethod
     def read_libsvm(path: str, **kwargs) -> pd.DataFrame:
         from sklearn.datasets import load_svmlight_file
         from joblib import Memory
+
         mem = Memory("./mycache")
 
         @mem.cache
@@ -523,6 +710,7 @@ class CustomFormatReaders:
     @staticmethod
     def read_avro(path: str, **kwargs) -> pd.DataFrame:
         from pandavro import read_avro
+
         return read_avro(path, **kwargs)
 
     DEFAULT_SQL_CHUNKSIZE = 12007
@@ -543,13 +731,20 @@ class CustomFormatReaders:
         """
         # ToDo: needs some love from the ADB story
         if table is None:
-            raise ValueError("In order to read from a database you need to specify the table using the `table` "
-                             "argument.")
+            raise ValueError(
+                "In order to read from a database you need to specify the table using the `table` "
+                "argument."
+            )
         # check if it's oracle dialect
-        if str(path).lower().startswith('oracle'):
-            kwargs = utils.inject_and_copy_kwargs(kwargs, **{"arraysize": cls.DEFAULT_SQL_ARRAYSIZE,
-                                                             "max_identifier_length": cls.DEFAULT_SQL_MIL,
-                                                             "coerce_to_unicode": cls.DEFAULT_SQL_CTU})
+        if str(path).lower().startswith("oracle"):
+            kwargs = utils.inject_and_copy_kwargs(
+                kwargs,
+                **{
+                    "arraysize": cls.DEFAULT_SQL_ARRAYSIZE,
+                    "max_identifier_length": cls.DEFAULT_SQL_MIL,
+                    "coerce_to_unicode": cls.DEFAULT_SQL_CTU,
+                },
+            )
         engine = utils.get_sqlalchemy_engine(path, **kwargs)
 
         table_name = table.strip()
@@ -558,31 +753,31 @@ class CustomFormatReaders:
             if table_name.lower().startswith("select"):
                 sql_query = table_name
             else:
-                utils.print_user_message(
-                    '''
-                    ADS now supports the ability to query based on a SQL expression.
-                    <h6>For example, </h6>
-                        <code>ds = DatasetFactory.open(uri, format="sql", table="SELECT prod_id, cust_id, time_id FROM SH.sales")</code>
-                    ''',
-                    display_type='info')
-                sql_query = f'select * from {table_name}'
+                sql_query = f"select * from {table_name}"
 
-            chunks = pd.read_sql_query(sql_query, con=connection,
-                                       **_validate_kwargs(pd.read_sql_query, utils.inject_and_copy_kwargs(kwargs,
-                                                                                                          **{
-                                                                                                              "chunksize": cls.DEFAULT_SQL_CHUNKSIZE})))
+            chunks = pd.read_sql_query(
+                sql_query,
+                con=connection,
+                **_validate_kwargs(
+                    pd.read_sql_query,
+                    utils.inject_and_copy_kwargs(
+                        kwargs, **{"chunksize": cls.DEFAULT_SQL_CHUNKSIZE}
+                    ),
+                ),
+            )
             df = pd.DataFrame()
             from tqdm import tqdm
-            with tqdm(chunks, unit=' rows') as t:
+
+            with tqdm(chunks, unit=" rows") as t:
                 for chunk in chunks:
                     df = pd.concat([df, chunk])
                     t.update(len(chunk))
 
             df = df.reset_index(drop=True)
             if df.shape[0] == 0:
-                utils.print_user_message(
-                    "The SQL expression returned no rows, no <code>ADSdataset</code> will be created",
-                    display_type='info')
+                logger.warning(
+                    "The SQL expression returned zero rows. Therefore, no `ADSdataset` object was created."
+                )
                 raise Exception("The SQL expression returned no rows")
         return df
 
@@ -594,20 +789,34 @@ class CustomFormatReaders:
             path,
             # assume_missing=True,
             sep=r'\s(?=(?:[^"]*"[^"]*")*[^"]*$)(?![^\[]*\])',
-            engine='python',
-            na_values='-',
+            engine="python",
+            na_values="-",
             header=None,
-            names=['host', 'identity', 'user', 'time', 'request',
-                   'http_code', 'response_bytes', 'referer', 'user_agent', 'unknown'],
-            converters={'time': parse_apache_log_datetime,
-                        'request': parse_apache_log_str,
-                        'status': int,
-                        'size': int,
-                        'referer': parse_apache_log_str,
-                        'user_agent': parse_apache_log_str},
-            **kwargs
+            names=[
+                "host",
+                "identity",
+                "user",
+                "time",
+                "request",
+                "http_code",
+                "response_bytes",
+                "referer",
+                "user_agent",
+                "unknown",
+            ],
+            converters={
+                "time": parse_apache_log_datetime,
+                "request": parse_apache_log_str,
+                "status": int,
+                "size": int,
+                "referer": parse_apache_log_str,
+                "user_agent": parse_apache_log_str,
+            },
+            **kwargs,
+        )
+        df["time"] = df["time"].map_partitions(
+            pd.to_datetime, utc=True, meta="datetime64[ns]"
         )
-        df["time"] = df["time"].map_partitions(pd.to_datetime, utc=True, meta='datetime64[ns]')
         return df
 
     @staticmethod
@@ -648,6 +857,7 @@ class CustomFormatReaders:
         dataframe : pandas.DataFrame
         """
         import xml.etree.cElementTree as et
+
         def get_children(df, node, parent, i):
 
             for name in node.attrib.keys():
@@ -660,7 +870,7 @@ class CustomFormatReaders:
 
         storage_options = kwargs.get("storage_options", {})
 
-        file_handles = fsspec.open_files(path, mode='rb', **storage_options)
+        file_handles = fsspec.open_files(path, mode="rb", **storage_options)
         ret_df = pd.DataFrame()
         last_i = 0
         for file_handle in file_handles:
@@ -694,13 +904,13 @@ reader_fns = {
     "clf": CustomFormatReaders.read_log,
     "html": CustomFormatReaders.read_html,
     "arff": CustomFormatReaders.read_arff,
-    "xml": CustomFormatReaders.read_xml
+    "xml": CustomFormatReaders.read_xml,
 }
 
 
 def _validate_kwargs(func: Callable, kwargs):
     valid_params = inspect.signature(func).parameters
-    if 'kwargs' in valid_params:
+    if "kwargs" in valid_params:
         return kwargs
     else:
         return {k: v for k, v in kwargs.items() if k in valid_params}
@@ -711,10 +921,12 @@ def get_format_reader(path: ElaboratedPath, **kwargs) -> Callable:
     try:
         reader_fn = reader_fns[format_key]
     except (KeyError, NameError):
-        raise ValueError(f'We were unable to load the specified dataset. We have interpreted the format '
-                         f'as {format_key}, if this is not correct, please call again and set the `format` parameter = '
-                         f'to the desired format. Read more here: https://docs.cloud.oracle.com/en-us/iaas/tools/ads'
-                         f'-sdk/latest/user_guide/loading_data/loading_data.html#specify-data-types-in-load-dataset')
+        raise ValueError(
+            f"We were unable to load the specified dataset. We have interpreted the format "
+            f"as {format_key}, if this is not correct, please call again and set the `format` parameter = "
+            f"to the desired format. Read more here: https://docs.cloud.oracle.com/en-us/iaas/tools/ads"
+            f"-sdk/latest/user_guide/loading_data/loading_data.html#specify-data-types-in-load-dataset"
+        )
 
     return reader_fn
 
@@ -722,25 +934,30 @@ def get_format_reader(path: ElaboratedPath, **kwargs) -> Callable:
 def load_dataset(path: ElaboratedPath, reader_fn: Callable, **kwargs) -> pd.DataFrame:
     dfs = []
     for filename in path.paths:
-        try:
-            dfs.append(reader_fn(filename, **_validate_kwargs(reader_fn, kwargs)))
-        except (ValueError, DatasetLoadException) as e:
-            raise e
+        data = reader_fn(filename, **_validate_kwargs(reader_fn, kwargs))
+        if not isinstance(data, pd.DataFrame):
+            fn_name = f"{reader_fn.__module__}.{reader_fn.__qualname__}"
+            raise ValueError(
+                f"{fn_name} is used to load the data. "
+                f"However, {fn_name} returned {type(data)} instead of pandas DataFrame. "
+                f"Please refer to the usage of {fn_name} to set the correct arguments."
+            )
+        dfs.append(data)
     if len(dfs) == 0:
-        raise ValueError(f'We were unable to load the specified dataset. Read more here: '
-                         f'https://docs.cloud.oracle.com/en-us/iaas/tools/ads'
-                         f'-sdk/latest/user_guide/loading_data/loading_data.html#specify-data-types-in-load-dataset')
+        raise ValueError(
+            f"We were unable to load the specified dataset. Read more here: "
+            f"https://docs.cloud.oracle.com/en-us/iaas/tools/ads"
+            f"-sdk/latest/user_guide/loading_data/loading_data.html#specify-data-types-in-load-dataset"
+        )
+
+    df = pd.concat(dfs)
 
-    try:
-        df = pd.concat(dfs)
-    except Exception as e:
-        assert all([isinstance(part, pd.DataFrame) for part in dfs]), "The Reader_fn should return a pandas dataset"
-        raise e
     if df is None:
-        raise ValueError(f'We were unable to load the specified dataset. Read more here: '
-                         f'https://docs.cloud.oracle.com/en-us/iaas/tools/ads'
-                         f'-sdk/latest/user_guide/loading_data/loading_data.html#specify-data-types-in-load-dataset')
+        raise ValueError(
+            f"We were unable to load the specified dataset. Read more here: "
+            f"https://docs.cloud.oracle.com/en-us/iaas/tools/ads"
+            f"-sdk/latest/user_guide/loading_data/loading_data.html#specify-data-types-in-load-dataset"
+        )
     if df.empty:
         raise DatasetLoadException("Empty DataFrame, not producing a ADSDataset")
     return df
-
