@@ -21,18 +21,26 @@ from folium import folium
 from folium.plugins import HeatMap
 from matplotlib import colors as mcolors
 from scipy.stats import gaussian_kde
+from ads.dataset.helper import _log_yscale_not_set
 
-from ads.common import utils
+from ads.common.utils import _log_plot_high_cardinality_warning, MAX_DISPLAY_VALUES
 from ads.type_discovery.latlon_detector import LatLonDetector
-from ads.type_discovery.typed_feature import ContinuousTypedFeature, DateTimeTypedFeature, \
-    ConstantTypedFeature, DiscreteTypedFeature, CreditCardTypedFeature, ZipcodeTypedFeature, OrdinalTypedFeature, \
-    CategoricalTypedFeature, GISTypedFeature
+from ads.type_discovery.typed_feature import (
+    ContinuousTypedFeature,
+    DateTimeTypedFeature,
+    ConstantTypedFeature,
+    DiscreteTypedFeature,
+    CreditCardTypedFeature,
+    ZipcodeTypedFeature,
+    OrdinalTypedFeature,
+    CategoricalTypedFeature,
+    GISTypedFeature,
+)
 
 from ads.dataset import logger
 
 
 class Plotting:
-
     def __init__(self, df, feature_types, x, y=None, plot_type="infer", yscale=None):
         self.df = df
         self.feature_types = feature_types
@@ -46,11 +54,11 @@ class Plotting:
     def __repr__(self):
         choices = self._get_plot_method()  # add (plot_type='{0}') in plot method"
         if len(choices) > 1:
-            utils.print_user_message("Recommended plot type: <code>{0}</code>, Available plot types: <code>{1}</code>\n" \
-                  "Add plot_type argument to plot method to choose a different plot type from the available " \
-                  "options. " \
-                  "For example, <code>ds.plot(“x”, y=“y”, plot_type='{0}')</code>" \
-                  .format(choices[0][1].__name__, ', '.join([x[1].__name__ for x in choices])))
+            logger.info(f"Recommended plot type is {choices[0][1].__name__}.")
+            logger.info(
+                "Available plot types are "
+                + ", ".join([x[1].name for x in choices] + ".")
+            )
         self.show_in_notebook()
         return ""
 
@@ -67,17 +75,23 @@ class Plotting:
 
         if len(choices) > 1:
             logger.info(
-                'select_best_plot (%s, %s) called, possible plot types are %s' % (
-                    self.x_type.meta_data["type"], self.y_type.meta_data["type"] if self.y_type is not None else ""
-                    , ', '.join([x[0].__name__ for x in choices])))
+                "select_best_plot (%s, %s) called, possible plot types are %s"
+                % (
+                    self.x_type.meta_data["type"],
+                    self.y_type.meta_data["type"] if self.y_type is not None else "",
+                    ", ".join([x[0].__name__ for x in choices]),
+                )
+            )
 
         if self.plot_type != "infer":
             for choice in choices:
                 if choice[1].__name__.lower().startswith(self.plot_type.lower()):
                     return choice
             logger.info("invalid plot_type: {}".format(self.plot_type))
-            raise ValueError("plot_type: '%s' invalid, use one of: %s" % (
-                self.plot_type, ', '.join([x[0].__name__ for x in choices])))
+            raise ValueError(
+                "plot_type: '%s' invalid, use one of: %s"
+                % (self.plot_type, ", ".join([x[0].__name__ for x in choices]))
+            )
 
         return choices[0]
 
@@ -106,7 +120,7 @@ class Plotting:
         return x_type.__name__ + "," + y_type.__name__
 
     @staticmethod
-    def _gaussian_heatmap(x, y, data, s=10, edgecolor='white', cmap=plt.cm.jet):
+    def _gaussian_heatmap(x, y, data, s=10, edgecolor="white", cmap=plt.cm.jet):
         """
         Generate a scatter plot and assign a color to each data point based on the local density (gaussian kernel) of
         points.
@@ -152,7 +166,7 @@ class Plotting:
         # when x is categorical, we set the order based on counts of each category
         vc = data[x].value_counts()
         if len(vc.keys()) > 10:
-            utils.print_user_message("Too many distinct values for {} ({:,}) to plot, only displaying top 10 values sorted by cardinality.".format(x, len(vc.keys())), display_type='info', title=None)
+            _log_plot_high_cardinality_warning(x, len(vc.keys()))
             idxes = vc[:10].index
         else:
             idxes = vc.index
@@ -167,8 +181,8 @@ class Plotting:
         freq = {}
         for items in sorted_x:
             freq[items] = sorted_x.count(items)
-        if len(freq) > 10:
-            utils.print_user_message("Too many distinct values for {} ({:,}) to plot, only displaying smallest 10 values sorted by x values.".format(x, len(freq)), display_type='info', title=None)
+        if len(freq) > MAX_DISPLAY_VALUES:
+            _log_plot_high_cardinality_warning(x, len(freq))
             idxes = list(freq.keys())[:10]
         else:
             idxes = freq.keys()
@@ -178,13 +192,13 @@ class Plotting:
     def _categorical_vs_continuous_horizontal_violin_plot(x, y, data):
         vc = data[x].value_counts()
         if len(vc.keys()) > 10:
-            utils.print_user_message(
-                "Too many distinct values for {} ({:,}) to plot, only displaying top 10 values sorted by cardinality.".format(x, len(vc.keys())),
-                display_type='info', title=None)
+            _log_plot_high_cardinality_warning(x, len(vc.keys()))
             idxes = vc[:10].index
         else:
             idxes = vc.index
-        sns.violinplot(x=y, y=x, data=data[data[x].isin(idxes)], order=idxes, orient='h')
+        sns.violinplot(
+            x=y, y=x, data=data[data[x].isin(idxes)], order=idxes, orient="h"
+        )
 
     @staticmethod
     def _ordinal_vs_continuous_horizontal_violin_plot(x, y, data):
@@ -195,20 +209,20 @@ class Plotting:
         freq = {}
         for items in sorted_x:
             freq[items] = sorted_x.count(items)
-        if len(freq) > 10:
-            utils.print_user_message("Too many distinct values for {} ({:,}) to plot, only displaying smallest 10 values sorted by x values.".format(x, len(freq)), display_type='info', title=None)
+        if len(freq) > MAX_DISPLAY_VALUES:
+            _log_plot_high_cardinality_warning(x, len(freq))
             idxes = list(freq.keys())[:10]
         else:
             idxes = freq.keys()
-        sns.violinplot(x=y, y=x, data=data[data[x].isin(idxes)], order=idxes, orient='h')
+        sns.violinplot(
+            x=y, y=x, data=data[data[x].isin(idxes)], order=idxes, orient="h"
+        )
 
     @staticmethod
     def _categorical_vs_continuous_box_plot(x, y, data):
         vc = data[x].value_counts()
         if len(vc.keys()) > 10:
-            utils.print_user_message(
-                "Too many distinct values for {} ({:,}) to plot, only displaying top 10 values sorted by cardinality.".format(x, len(vc.keys())),
-                display_type='info', title=None)
+            _log_plot_high_cardinality_warning(x, len(vc.keys()))
             idxes = vc[:10].index
         else:
             idxes = vc.index
@@ -223,8 +237,8 @@ class Plotting:
         freq = {}
         for items in sorted_x:
             freq[items] = sorted_x.count(items)
-        if len(freq) > 10:
-            utils.print_user_message("Too many distinct values for {} ({:,}) to plot, only displaying smallest 10 values sorted by x values.".format(x, len(freq)), display_type='info', title=None)
+        if len(freq) > MAX_DISPLAY_VALUES:
+            _log_plot_high_cardinality_warning(x, len(freq))
             idxes = list(freq.keys())[:10]
         else:
             idxes = freq.keys()
@@ -239,18 +253,17 @@ class Plotting:
         freq = {}
         for items in sorted_x:
             freq[items] = sorted_x.count(items)
-        if len(freq) > 10:
-            utils.print_user_message("Too many distinct values for {} ({:,}) to plot, only displaying smallest 10 values sorted by x values.".format(x, len(freq)), display_type='info', title=None)
+        if len(freq) > MAX_DISPLAY_VALUES:
+            _log_plot_high_cardinality_warning(x, len(freq))
             idxes = list(freq.keys())[:10]
         else:
             idxes = freq.keys()
-        sns.boxplot(x=y, y=x, data=data[data[x].isin(idxes)], order=idxes, orient='h')
-
+        sns.boxplot(x=y, y=x, data=data[data[x].isin(idxes)], order=idxes, orient="h")
 
     @staticmethod
     def _count_plot(x, hue, data, yscale=None):
         if not yscale:
-            utils.print_user_message("Set yscale to one of <code>'linear'</code>, <code>'log'</code>, <code>'symlog'</code> to apply scale to y axis")
+            _log_yscale_not_set()
         # get the copy of data and convert categorical data type to object
         data = data.copy()
         data[hue] = data[hue].astype("object")
@@ -259,7 +272,9 @@ class Plotting:
         if len(cat_cardi) > 5:
             top_categoricals = cat_cardi[:5].index
             # modify the data to replace non top 5 categorical values to be the same value
-            data[hue] = np.where(data[hue].isin(top_categoricals), data[hue], 'all_other_categories')
+            data[hue] = np.where(
+                data[hue].isin(top_categoricals), data[hue], "all_other_categories"
+            )
             cat_index = data[hue].value_counts().index
         else:
             cat_index = cat_cardi.index
@@ -276,13 +291,14 @@ class Plotting:
     @staticmethod
     def _ordinal_count_plot(x, data, yscale=None):
         if not yscale:
-            utils.print_user_message("Set yscale to one of <code>'linear'</code>, <code>'log'</code>, <code>'symlog'</code> to apply scale to y axis")
-
+            _log_yscale_not_set()
         data = data.copy()
         ordi_cardi = data[x].value_counts()
         if len(ordi_cardi) > 20:
             intervals = pd.cut(data[x], 20, precision=0)
-            intervals = intervals.apply(lambda k: pd.Interval(int(k.left), int(k.right)))
+            intervals = intervals.apply(
+                lambda k: pd.Interval(int(k.left), int(k.right))
+            )
         else:
             intervals = data[x]
         g = sns.countplot(x=intervals, color="#1f77b4")
@@ -292,7 +308,7 @@ class Plotting:
     @staticmethod
     def _ordinal_vs_constant_count_plot(x, hue, data, yscale=None):
         if not yscale:
-            utils.print_user_message("Set yscale to one of <code>'linear'</code>, <code>'log'</code>, <code>'symlog'</code> to apply scale to y axis")
+            _log_yscale_not_set()
         data = data.copy()
         intervals = pd.cut(data[x], 20, precision=0)
         intervals = intervals.apply(lambda k: pd.Interval(int(k.left), int(k.right)))
@@ -303,8 +319,7 @@ class Plotting:
     @staticmethod
     def _single_column_count_plot(x, data, yscale=None):
         if not yscale:
-            utils.print_user_message(
-                "Set yscale to one of <code>'linear'</code>, <code>'log'</code>, <code>'symlog'</code> to apply scale to y axis")
+            _log_yscale_not_set()
         order = data[x].value_counts().iloc[:24].index
         g = sns.countplot(x=x, data=data, order=order)
         if yscale:
@@ -313,8 +328,13 @@ class Plotting:
     @staticmethod
     def _folium_map(x, data):
         df = LatLonDetector.extract_x_y(data[x])
-        lat_min, lat_max, long_min, long_max = min(df.Y), max(df.Y), min(df.X), max(df.X)
-        m = folium.Map(tiles='Stamen Terrain', zoom_control=False)
+        lat_min, lat_max, long_min, long_max = (
+            min(df.Y),
+            max(df.Y),
+            min(df.X),
+            max(df.X),
+        )
+        m = folium.Map(tiles="Stamen Terrain", zoom_control=False)
 
         HeatMap(df[["Y", "X"]]).add_to(m)
         m.fit_bounds([[lat_min, long_min], [lat_max, long_max]])
@@ -327,7 +347,11 @@ class Plotting:
     @staticmethod
     def _multiple_pdf(x, y, data):
         colors = dict(mcolors.BASE_COLORS, **mcolors.CSS4_COLORS)
-        hues = [colors[x] for x in colors.keys() if isinstance(colors[x], str) and colors[x].startswith('#')]
+        hues = [
+            colors[x]
+            for x in colors.keys()
+            if isinstance(colors[x], str) and colors[x].startswith("#")
+        ]
 
         for i, cat in enumerate(list(data[y].unique())):
             s = data.loc[data[y] == cat][x]
@@ -338,29 +362,34 @@ class Plotting:
 
     def _matplot(self, plot_method, figsize=(4, 3), **kwargs):
 
-        plt.style.use('seaborn-white')
+        plt.style.use("seaborn-white")
 
-        plt.rc('xtick', labelsize='x-small')
-        plt.rc('ytick', labelsize='x-small')
-        plt.rc('font', size=8)
-        plt.rc('figure', dpi=144)
+        plt.rc("xtick", labelsize="x-small")
+        plt.rc("ytick", labelsize="x-small")
+        plt.rc("font", size=8)
+        plt.rc("figure", dpi=144)
 
         fig = plt.figure(figsize=figsize)
 
         #
         # generate a title for the plot
         #
-        text = '{}, "{}" ({})'.format(plot_method.__name__.upper(), self.x, self.feature_types[self.x].type)
+        text = '{}, "{}" ({})'.format(
+            plot_method.__name__.upper(), self.x, self.feature_types[self.x].type
+        )
         if self.y:
-            text = '{} vs "{}" ({})'.format(text, self.y, self.feature_types[self.y].type)
+            text = '{} vs "{}" ({})'.format(
+                text, self.y, self.feature_types[self.y].type
+            )
 
         plt.title(text, y=1.08)
-        plt.grid(linestyle='dotted')
+        plt.grid(linestyle="dotted")
 
         # draw a 45 degree dotted or dashed line indicating equality when plot method is scatter plots and the span of x equals the span of y
-        if (plot_method is plt.scatter or plot_method is Plotting._gaussian_heatmap) \
-                and (self.df[kwargs['x']].values.ptp() == self.df[kwargs['y']].values.ptp()):
-            Plotting._add_identity(fig.axes[0], color='grey', ls='--')
+        if (
+            plot_method is plt.scatter or plot_method is Plotting._gaussian_heatmap
+        ) and (self.df[kwargs["x"]].values.ptp() == self.df[kwargs["y"]].values.ptp()):
+            Plotting._add_identity(fig.axes[0], color="grey", ls="--")
 
         plot_method(**kwargs, data=self.df)
 
@@ -379,7 +408,17 @@ class Plotting:
         if plot_method is plt.hist:
             plt.ylabel("instance count")
             # add tickmark on x-axis to see labeled values on x-axis in historgram. It has 30 intervals because that's the most tickmarks on graph can fit.
-            plt.xticks(np.arange(min(self.df[kwargs['x']].values), max(self.df[kwargs['x']].values)+1, (max(self.df[kwargs['x']].values)-min(self.df[kwargs['x']].values))/30))
+            plt.xticks(
+                np.arange(
+                    min(self.df[kwargs["x"]].values),
+                    max(self.df[kwargs["x"]].values) + 1,
+                    (
+                        max(self.df[kwargs["x"]].values)
+                        - min(self.df[kwargs["x"]].values)
+                    )
+                    / 30,
+                )
+            )
         # override y-axis label as "count" when plot type is _count_plot or countplot
         if plot_method is Plotting._count_plot or plot_method is sns.countplot:
             plt.ylabel("count")
@@ -399,68 +438,220 @@ class Plotting:
 
         combos = defaultdict(list)
 
-        combos[Plotting._build_plot_key(CategoricalTypedFeature, ContinuousTypedFeature)] = [
-            (self._matplot, Plotting._categorical_vs_continuous_violin_plot, {"x": self.x, "y": self.y}),
-            (self._matplot, Plotting._categorical_vs_continuous_box_plot, {"x": self.x, "y": self.y})]
-        combos[Plotting._build_plot_key(OrdinalTypedFeature, ContinuousTypedFeature)] = [
-            (self._matplot, Plotting._ordinal_vs_continuous_violin_plot, {"x": self.x, "y": self.y}),
-            (self._matplot, Plotting._ordinal_vs_continuous_box_plot, {"x": self.x, "y": self.y})]
-        combos[Plotting._build_plot_key(ContinuousTypedFeature, OrdinalTypedFeature)] = [
-            (self._matplot, Plotting._ordinal_vs_continuous_horizontal_violin_plot, {"x": self.y, "y": self.x}),
-            (self._matplot, Plotting._ordinal_vs_continuous_horizontal_box_plot, {"x": self.y, "y": self.x})]
-        combos[Plotting._build_plot_key(ContinuousTypedFeature, CategoricalTypedFeature)] = [
-            (self._matplot, Plotting._multiple_pdf, {"x": self.x, "y": self.y})]
-        combos[Plotting._build_plot_key(ConstantTypedFeature, ContinuousTypedFeature)] = [
-            (self._matplot, sns.barplot, {"x": self.x, "y": self.y})]
-        combos[Plotting._build_plot_key(ContinuousTypedFeature, ConstantTypedFeature)] = [
-            (self._matplot, Plotting._single_pdf, {"x": self.x, "y": self.y})]
+        combos[
+            Plotting._build_plot_key(CategoricalTypedFeature, ContinuousTypedFeature)
+        ] = [
+            (
+                self._matplot,
+                Plotting._categorical_vs_continuous_violin_plot,
+                {"x": self.x, "y": self.y},
+            ),
+            (
+                self._matplot,
+                Plotting._categorical_vs_continuous_box_plot,
+                {"x": self.x, "y": self.y},
+            ),
+        ]
+        combos[
+            Plotting._build_plot_key(OrdinalTypedFeature, ContinuousTypedFeature)
+        ] = [
+            (
+                self._matplot,
+                Plotting._ordinal_vs_continuous_violin_plot,
+                {"x": self.x, "y": self.y},
+            ),
+            (
+                self._matplot,
+                Plotting._ordinal_vs_continuous_box_plot,
+                {"x": self.x, "y": self.y},
+            ),
+        ]
+        combos[
+            Plotting._build_plot_key(ContinuousTypedFeature, OrdinalTypedFeature)
+        ] = [
+            (
+                self._matplot,
+                Plotting._ordinal_vs_continuous_horizontal_violin_plot,
+                {"x": self.y, "y": self.x},
+            ),
+            (
+                self._matplot,
+                Plotting._ordinal_vs_continuous_horizontal_box_plot,
+                {"x": self.y, "y": self.x},
+            ),
+        ]
+        combos[
+            Plotting._build_plot_key(ContinuousTypedFeature, CategoricalTypedFeature)
+        ] = [(self._matplot, Plotting._multiple_pdf, {"x": self.x, "y": self.y})]
+        combos[
+            Plotting._build_plot_key(ConstantTypedFeature, ContinuousTypedFeature)
+        ] = [(self._matplot, sns.barplot, {"x": self.x, "y": self.y})]
+        combos[
+            Plotting._build_plot_key(ContinuousTypedFeature, ConstantTypedFeature)
+        ] = [(self._matplot, Plotting._single_pdf, {"x": self.x, "y": self.y})]
         combos[Plotting._build_plot_key(ConstantTypedFeature, DiscreteTypedFeature)] = [
-            (self._matplot, sns.barplot, {"x": self.x, "y": self.y})]
+            (self._matplot, sns.barplot, {"x": self.x, "y": self.y})
+        ]
         combos[Plotting._build_plot_key(DiscreteTypedFeature, ConstantTypedFeature)] = [
-            (self._matplot, Plotting._ordinal_vs_constant_count_plot, {"x": self.x, "hue": self.y, "yscale": self.yscale})]
-        combos[Plotting._build_plot_key(DateTimeTypedFeature, ContinuousTypedFeature)] = [
-            (self._matplot, plt.scatter,
-             {"x": self.x, "y": self.y, "s": pi / 10 * (matplotlib.rcParams['lines.markersize'] ** 2), "edgecolor": "white", "linewidths": "0.1"})]
+            (
+                self._matplot,
+                Plotting._ordinal_vs_constant_count_plot,
+                {"x": self.x, "hue": self.y, "yscale": self.yscale},
+            )
+        ]
+        combos[
+            Plotting._build_plot_key(DateTimeTypedFeature, ContinuousTypedFeature)
+        ] = [
+            (
+                self._matplot,
+                plt.scatter,
+                {
+                    "x": self.x,
+                    "y": self.y,
+                    "s": pi / 10 * (matplotlib.rcParams["lines.markersize"] ** 2),
+                    "edgecolor": "white",
+                    "linewidths": "0.1",
+                },
+            )
+        ]
         combos[Plotting._build_plot_key(DateTimeTypedFeature, OrdinalTypedFeature)] = [
-            (self._matplot, plt.scatter, {"x": self.x, "y": self.y, "edgecolor": "white", "linewidths": "0.1"})]
-        combos[Plotting._build_plot_key(ContinuousTypedFeature, ContinuousTypedFeature)] = [
-            (self._matplot, Plotting._gaussian_heatmap,
-             {"x": self.x, "y": self.y, "s": pi / 10 * (matplotlib.rcParams['lines.markersize'] ** 2)}),
-            (self._matplot, plt.scatter, {"x": self.x, "y": self.y, "edgecolor": "white", "linewidths": "0.1"})]
+            (
+                self._matplot,
+                plt.scatter,
+                {"x": self.x, "y": self.y, "edgecolor": "white", "linewidths": "0.1"},
+            )
+        ]
+        combos[
+            Plotting._build_plot_key(ContinuousTypedFeature, ContinuousTypedFeature)
+        ] = [
+            (
+                self._matplot,
+                Plotting._gaussian_heatmap,
+                {
+                    "x": self.x,
+                    "y": self.y,
+                    "s": pi / 10 * (matplotlib.rcParams["lines.markersize"] ** 2),
+                },
+            ),
+            (
+                self._matplot,
+                plt.scatter,
+                {"x": self.x, "y": self.y, "edgecolor": "white", "linewidths": "0.1"},
+            ),
+        ]
         combos[Plotting._build_plot_key(OrdinalTypedFeature, OrdinalTypedFeature)] = [
-            (self._matplot, sns.scatterplot,
-             {"x": self.x, "y": self.y, "s": pi / 10 * (matplotlib.rcParams['lines.markersize'] ** 2), "edgecolor": "white", "linewidths": "0.1"})]
+            (
+                self._matplot,
+                sns.scatterplot,
+                {
+                    "x": self.x,
+                    "y": self.y,
+                    "s": pi / 10 * (matplotlib.rcParams["lines.markersize"] ** 2),
+                    "edgecolor": "white",
+                    "linewidths": "0.1",
+                },
+            )
+        ]
         combos[Plotting._build_plot_key(OrdinalTypedFeature, DiscreteTypedFeature)] = [
-            (self._matplot, sns.countplot, {"x": self.x, "hue": self.y})]
-        combos[Plotting._build_plot_key(OrdinalTypedFeature, CategoricalTypedFeature)] = [
-            (self._matplot, Plotting._count_plot, {"x": self.x, "hue": self.y, "yscale": self.yscale})]
-        combos[Plotting._build_plot_key(CategoricalTypedFeature, OrdinalTypedFeature)] = [
-            (self._matplot, Plotting._count_plot, {"x": self.y, "hue": self.x, "yscale": self.yscale})]
+            (self._matplot, sns.countplot, {"x": self.x, "hue": self.y})
+        ]
+        combos[
+            Plotting._build_plot_key(OrdinalTypedFeature, CategoricalTypedFeature)
+        ] = [
+            (
+                self._matplot,
+                Plotting._count_plot,
+                {"x": self.x, "hue": self.y, "yscale": self.yscale},
+            )
+        ]
+        combos[
+            Plotting._build_plot_key(CategoricalTypedFeature, OrdinalTypedFeature)
+        ] = [
+            (
+                self._matplot,
+                Plotting._count_plot,
+                {"x": self.y, "hue": self.x, "yscale": self.yscale},
+            )
+        ]
         combos[Plotting._build_plot_key(DiscreteTypedFeature, OrdinalTypedFeature)] = [
-            (self._matplot, sns.countplot,
-             {"x": self.x, "hue": self.y, "order": self.df[self.x].value_counts(ascending=True).iloc[:10].index})]
-        combos[Plotting._build_plot_key(DiscreteTypedFeature, CategoricalTypedFeature)] = [
-            (self._matplot, sns.countplot, {"x": self.x, "hue": self.y, "order": self.df[self.x].value_counts().iloc[:10].index})]
+            (
+                self._matplot,
+                sns.countplot,
+                {
+                    "x": self.x,
+                    "hue": self.y,
+                    "order": self.df[self.x]
+                    .value_counts(ascending=True)
+                    .iloc[:10]
+                    .index,
+                },
+            )
+        ]
+        combos[
+            Plotting._build_plot_key(DiscreteTypedFeature, CategoricalTypedFeature)
+        ] = [
+            (
+                self._matplot,
+                sns.countplot,
+                {
+                    "x": self.x,
+                    "hue": self.y,
+                    "order": self.df[self.x].value_counts().iloc[:10].index,
+                },
+            )
+        ]
         combos[Plotting._build_plot_key(DateTimeTypedFeature, DateTimeTypedFeature)] = [
-            (self._matplot, plt.scatter,
-             {"x": self.x, "y": self.y, "s": pi / 10 * (matplotlib.rcParams['lines.markersize'] ** 2), "edgecolor": "white", "linewidths": "0.1"})]
+            (
+                self._matplot,
+                plt.scatter,
+                {
+                    "x": self.x,
+                    "y": self.y,
+                    "s": pi / 10 * (matplotlib.rcParams["lines.markersize"] ** 2),
+                    "edgecolor": "white",
+                    "linewidths": "0.1",
+                },
+            )
+        ]
 
-        combos[Plotting._build_plot_key(ContinuousTypedFeature, None)] = [(self._matplot, plt.hist, {"x": self.x})]
+        combos[Plotting._build_plot_key(ContinuousTypedFeature, None)] = [
+            (self._matplot, plt.hist, {"x": self.x})
+        ]
         combos[Plotting._build_plot_key(CategoricalTypedFeature, None)] = [
-            (self._matplot, Plotting._single_column_count_plot, {"x": self.x, "yscale": self.yscale})]
+            (
+                self._matplot,
+                Plotting._single_column_count_plot,
+                {"x": self.x, "yscale": self.yscale},
+            )
+        ]
         combos[Plotting._build_plot_key(OrdinalTypedFeature, None)] = [
-            (self._matplot, Plotting._ordinal_count_plot, {"x": self.x, "yscale": self.yscale})]
-        combos[Plotting._build_plot_key(ConstantTypedFeature, None)] = [(self._matplot, sns.countplot, {"x": self.x})]
-        combos[Plotting._build_plot_key(DateTimeTypedFeature, None)] = [(self._matplot, plt.hist, {"x": self.x, "bins": 10, "color": "#1f77b4"})]
-        combos[Plotting._build_plot_key(GISTypedFeature, None)] = [(self._generic_plot, Plotting._folium_map, {"x": self.x})]
+            (
+                self._matplot,
+                Plotting._ordinal_count_plot,
+                {"x": self.x, "yscale": self.yscale},
+            )
+        ]
+        combos[Plotting._build_plot_key(ConstantTypedFeature, None)] = [
+            (self._matplot, sns.countplot, {"x": self.x})
+        ]
+        combos[Plotting._build_plot_key(DateTimeTypedFeature, None)] = [
+            (self._matplot, plt.hist, {"x": self.x, "bins": 10, "color": "#1f77b4"})
+        ]
+        combos[Plotting._build_plot_key(GISTypedFeature, None)] = [
+            (self._generic_plot, Plotting._folium_map, {"x": self.x})
+        ]
 
         y_type_name = None if self.y_type is None else self.y_type.__class__
-        keys_to_check = list([Plotting._build_plot_key(self.x_type.__class__, y_type_name)])
+        keys_to_check = list(
+            [Plotting._build_plot_key(self.x_type.__class__, y_type_name)]
+        )
 
         new_x_type = Plotting._change_type(self.x_type)
         new_y_type = Plotting._change_type(self.y_type)
         keys_to_check.append(Plotting._build_plot_key(new_x_type, y_type_name))
-        keys_to_check.append(Plotting._build_plot_key(self.x_type.__class__, new_y_type))
+        keys_to_check.append(
+            Plotting._build_plot_key(self.x_type.__class__, new_y_type)
+        )
         keys_to_check.append(Plotting._build_plot_key(new_x_type, new_y_type))
         for key in keys_to_check:
             if key in combos and combos[key]:
@@ -468,18 +659,27 @@ class Plotting:
                 return combos[key]
 
         if y_type_name is not None:
-            raise NotImplementedError("Plotting for the feature combination ({0} vs {1}) is not yet supported."
-                                      .format(self.x_type.meta_data["type"], self.y_type.meta_data["type"]))
+            raise NotImplementedError(
+                "Plotting for the feature combination ({0} vs {1}) is not yet supported.".format(
+                    self.x_type.meta_data["type"], self.y_type.meta_data["type"]
+                )
+            )
         else:
-            raise NotImplementedError("Plotting for feature type {0} is not supported"
-                                      .format(self.x_type.meta_data["type"]))
+            raise NotImplementedError(
+                "Plotting for feature type {0} is not supported".format(
+                    self.x_type.meta_data["type"]
+                )
+            )
 
     def _change_type(feature_type):
         if feature_type is None:
             return None
 
-        return DiscreteTypedFeature if isinstance(feature_type, DiscreteTypedFeature) or isinstance(feature_type,
-                                                                                                    CreditCardTypedFeature) \
-                                       or isinstance(feature_type, ZipcodeTypedFeature) or isinstance(feature_type,
-                                                                                                      OrdinalTypedFeature) \
+        return (
+            DiscreteTypedFeature
+            if isinstance(feature_type, DiscreteTypedFeature)
+            or isinstance(feature_type, CreditCardTypedFeature)
+            or isinstance(feature_type, ZipcodeTypedFeature)
+            or isinstance(feature_type, OrdinalTypedFeature)
             else feature_type.__class__
+        )
