@@ -14,7 +14,6 @@ from tqdm import tqdm_notebook
 
 
 class ProgressBar(object):
-
     @abstractmethod
     def __enter__(self):
         pass
@@ -47,7 +46,10 @@ class IpythonProgressBar(ProgressBar):
         Updates the progress bar
         """
         if self.verbose:
-            print(str.format('{0:.3f}', time.time() - self.start_time), self.progress_label.value)
+            print(
+                str.format("{0:.3f}", time.time() - self.start_time),
+                self.progress_label.value,
+            )
             self.start_time = time.time()
         self.progress_bar.value += 1
         if description is not None:
@@ -67,7 +69,9 @@ class TqdmProgressBar(ProgressBar):
 
     def __init__(self, max_progress=100, description="Running", verbose=False):
         self.max_progress = max_progress
-        self.progress_bar = tqdm_notebook(range(max_progress), desc='loop1', mininterval=0, leave=False)
+        self.progress_bar = tqdm_notebook(
+            range(max_progress), desc="loop1", mininterval=0, leave=False
+        )
         self.progress_bar.set_description(description)
         self.verbose = verbose
         if self.verbose:
@@ -79,8 +83,16 @@ class TqdmProgressBar(ProgressBar):
         Updates the progress bar
         """
         if self.verbose and description is not None:
-            print("%s:%ss" % (self.description, str.format('{0:.3f}', time.time() - self.start_time)))
-            self.description = description if description is not None else self.description
+            print(
+                "%s:%ss"
+                % (
+                    self.description,
+                    str.format("{0:.3f}", time.time() - self.start_time),
+                )
+            )
+            self.description = (
+                description if description is not None else self.description
+            )
             self.start_time = time.time()
         self.progress_bar.update(1)
         if description is not None:
