@@ -13,6 +13,7 @@ from abc import abstractmethod
 from tqdm import tqdm_notebook
 import six
 
+
 class ProgressBar(object):
     """ProgressBar is an abstract class for creating progress bars.
 
@@ -68,8 +69,7 @@ class TqdmProgressBar(ProgressBar):
     """
 
     def __enter__(self):
-        """__enter__ runs when the context starts. It returns the class object
-        """
+        """__enter__ runs when the context starts. It returns the class object"""
         return self
 
     def __init__(self, max_progress=100, description="Running", verbose=False):
@@ -82,7 +82,9 @@ class TqdmProgressBar(ProgressBar):
         """
 
         self.max_progress = max_progress
-        self.progress_bar = tqdm_notebook(range(max_progress), desc='loop1', mininterval=0, leave=False)
+        self.progress_bar = tqdm_notebook(
+            range(max_progress), desc="loop1", mininterval=0, leave=False
+        )
         self.progress_bar.set_description(description)
         self.verbose = verbose
         if self.verbose:
@@ -100,8 +102,16 @@ class TqdmProgressBar(ProgressBar):
         """
 
         if self.verbose and description is not None:
-            print("%s:%ss" % (self.description, str.format('{0:.3f}', time.time() - self.start_time)))
-            self.description = description if description is not None else self.description
+            print(
+                "%s:%ss"
+                % (
+                    self.description,
+                    str.format("{0:.3f}", time.time() - self.start_time),
+                )
+            )
+            self.description = (
+                description if description is not None else self.description
+            )
             self.start_time = time.time()
         self.progress_bar.update(1)
         if description is not None:
@@ -109,7 +119,7 @@ class TqdmProgressBar(ProgressBar):
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         """__exit__ runs when the context closes. On success, i.e. all arguments are None
-        it sets the description and closes the context. Otherwise it reraises an exception 
+        it sets the description and closes the context. Otherwise it reraises an exception
         thrown in the context
 
         Args:
