@@ -7,20 +7,15 @@
 
 # Standard library
 from typing import Union, List, Optional
-import json
 import os
 
 # Third party
 import pandas as pd
-import requests
-import yaml
 
 # Oracle
 from .common import utils
 from .common.utils import OCIClientManager, State
-from oci.signer import Signer
 import oci
-import oci.data_science.models as data_science_models
 
 from .model_deployment import ModelDeployment, DEFAULT_WAIT_TIME, DEFAULT_POLL_INTERVAL
 from .model_deployment_properties import ModelDeploymentProperties
@@ -73,23 +68,48 @@ class ModelDeployer:
     delete(model_deployment_id, **kwargs)
         Remove the model deployment specified by the id or Model Deployment Object
     list_deployments(status)
-        lists the model deployments associated with current compartment and data 
+        lists the model deployments associated with current compartment and data
         science client
     show_deployments(status)
-        shows the deployments filterd by `status` in a Dataframe
+        shows the deployments filtered by `status` in a Dataframe
 
     """
 
     def __init__(self, config=None):
+        """Initializes ModelDeployer with optional config
+
+        Args:
+            config (dict or str, optional): Configurations,
+                which can be a dictionary or the path of YAML containing the config.
+                If None, default config will be used.
+
+        Configurations
+        --------------
+        The following keys can be used in the config:
+        auth: Authentication method, must be either "resource_principal" or "api_key".
+            If auth is not specified:
+                1. api_key will be used if available.
+                2. If api_key is not available, resource_principal will be used.
+        oci_config_file: OCI API key config file location. Defaults to "~/.oci/config"
+        oci_config_profile: OCI API key config profile name. Defaults to "DEFAULT"
+        oci_odsc_service_endpoint: URL of the service endpoint. Defaults to OCI production endpoint.
+            This is for debugging/integration testing purpose.
+        """
         # self.config contains contents of yml file/dict passed in by user
         self.config = utils.load_config(config)
-        self.service_endpoint = self.config.get("OCI_ODSC_SERVICE_ENDPOINT")
         self.ds_client = OCIClientManager.oci_ds_client(self.config)
-        self.ds_composite_client = OCIClientManager.oci_ds_composite_client(self.ds_client)
+        self.ds_composite_client = OCIClientManager.oci_ds_composite_client(
+            self.ds_client
+        )
 
-    def deploy(self, properties=None, wait_for_completion:bool = True,
-            max_wait_time: int = DEFAULT_WAIT_TIME, poll_interval: int = DEFAULT_POLL_INTERVAL, 
-            **kwargs) -> ModelDeployment:
+    def deploy(
+        self,
+        properties=None,
+        wait_for_completion: bool = True,
+        max_wait_time: int = DEFAULT_WAIT_TIME,
+        poll_interval: int = DEFAULT_POLL_INTERVAL,
+        **kwargs
+    ) -> ModelDeployment:
         """Deploys a model.
 
         Args:
@@ -104,19 +124,31 @@ class ModelDeployer:
         Returns:
             ModelDeployment: ModelDeployment objects that was deployed
         """
-        model_deployment = ModelDeployment(properties, config=self.config,
-                                            ds_client=self.ds_client, 
-                                            ds_composite_client=self.ds_composite_client, **kwargs)
-        return model_deployment.deploy(wait_for_completion, max_wait_time, poll_interval)
+        model_deployment = ModelDeployment(
+            properties,
+            config=self.config,
+            ds_client=self.ds_client,
+            ds_composite_client=self.ds_composite_client,
+            **kwargs
+        )
+        return model_deployment.deploy(
+            wait_for_completion, max_wait_time, poll_interval
+        )
 
-    def update(self, model_deployment_id: str, properties: ModelDeploymentProperties = None, wait_for_completion:bool = True,
-            max_wait_time: int = DEFAULT_WAIT_TIME, poll_interval: int = DEFAULT_POLL_INTERVAL,
-            **kwargs) -> ModelDeployment:
+    def update(
+        self,
+        model_deployment_id: str,
+        properties: ModelDeploymentProperties = None,
+        wait_for_completion: bool = True,
+        max_wait_time: int = DEFAULT_WAIT_TIME,
+        poll_interval: int = DEFAULT_POLL_INTERVAL,
+        **kwargs
+    ) -> ModelDeployment:
         """Updates an existing model deployment.
 
         Args:
             model_deployment_id (str): Model deployment OCID
-            properties (ModelDeploymentProperties, optional): An instance of ModelDeploymentProperties or 
+            properties (ModelDeploymentProperties, optional): An instance of ModelDeploymentProperties or
                 dict to initialize the ModelDeploymentProperties. Defaults to None.
             wait_for_completion (bool, optional): Flag set for whether to wait for deployment to complete before
                 proceeding. Defaults to True
@@ -128,21 +160,18 @@ class ModelDeployer:
             ModelDeployment: a ModelDeployment object
 
         """
-        try:
-            model_deployment = self.get_model_deployment(model_deployment_id)
-            # Deployment properties will be refreshed within model_deployment.update() when update is done.
-            return model_deployment.update(
-                properties,
-                wait_for_completion,
-                max_wait_time=max_wait_time,
-                poll_interval=poll_interval,
-                **kwargs
-            )
-        except Exception as e:
-            utils.get_logger().error("Updating model deployment failed with error: %s", format(e))
-            raise e
-    
-    def get_model_deployment(self, model_deployment_id:str) -> ModelDeployment:
+
+        model_deployment = self.get_model_deployment(model_deployment_id)
+        # Deployment properties will be refreshed within model_deployment.update() when update is done.
+        return model_deployment.update(
+            properties,
+            wait_for_completion,
+            max_wait_time=max_wait_time,
+            poll_interval=poll_interval,
+            **kwargs
+        )
+
+    def get_model_deployment(self, model_deployment_id: str) -> ModelDeployment:
         """get_model_deployment returns the ModelDeployment specified by `model_deployment_id`.
 
         Args:
@@ -153,19 +182,23 @@ class ModelDeployer:
         """
 
         try:
-            oci_model_deployment_object = self.ds_client.get_model_deployment(model_deployment_id).data
+            oci_model_deployment_object = self.ds_client.get_model_deployment(
+                model_deployment_id
+            ).data
             model_deployment_object = ModelDeployment(
                 oci_model_deployment_object,
                 config=self.config,
                 ds_client=self.ds_client,
-                ds_composite_client=self.ds_composite_client
+                ds_composite_client=self.ds_composite_client,
             )
             return model_deployment_object
         except Exception as e:
-            utils.get_logger().error("Getting model deployment failed with error: %s", e)
+            utils.get_logger().error(
+                "Getting model deployment failed with error: %s", e
+            )
             raise e
 
-    def get_model_deployment_state(self, model_deployment_id:str) -> State:
+    def get_model_deployment_state(self, model_deployment_id: str) -> State:
         """get_model_deployment_state returns the state of the current deployment specified by id
 
         Args:
@@ -178,14 +211,19 @@ class ModelDeployer:
         model_deployment = self.get_model_deployment(model_deployment_id)
         return model_deployment.state
 
-    def delete(self, model_deployment_id, wait_for_completion:bool = True, 
-            max_wait_time: int = DEFAULT_WAIT_TIME, poll_interval: int = DEFAULT_POLL_INTERVAL) -> ModelDeployment:
+    def delete(
+        self,
+        model_deployment_id,
+        wait_for_completion: bool = True,
+        max_wait_time: int = DEFAULT_WAIT_TIME,
+        poll_interval: int = DEFAULT_POLL_INTERVAL,
+    ) -> ModelDeployment:
         """delete removes the model deployment specified by the id or Model Deployment Object
 
         Args:
             model_deployment (str): the model deployment ocid
             wait_for_completion (bool, optional): Wait for deletion to complete. Defaults to True.
-            max_wait_time (int, optional): Maximum amount of time to wait in seconds (Defaults to 600). 
+            max_wait_time (int, optional): Maximum amount of time to wait in seconds (Defaults to 600).
                 Negative implies infinite wait time.
             poll_interval (int, optional): Poll interval in seconds (Defaults to 60).
 
@@ -194,13 +232,17 @@ class ModelDeployer:
         """
         try:
             model_deployment_object = self.get_model_deployment(model_deployment_id)
-            return model_deployment_object.delete(wait_for_completion, max_wait_time, poll_interval)
+            return model_deployment_object.delete(
+                wait_for_completion, max_wait_time, poll_interval
+            )
         except Exception as e:
-            utils.get_logger().error("Deleting model deployment failed with error: %s", format(e))
+            utils.get_logger().error(
+                "Deleting model deployment failed with error: %s", format(e)
+            )
             raise e
 
     def list_deployments(self, status=None, compartment_id=None, **kwargs) -> list:
-        """ Lists the model deployments associated with current compartment and data science client
+        """Lists the model deployments associated with current compartment and data science client
 
         Args:
             status (str, optional): Status of deployment. Defaults to None.
@@ -220,29 +262,33 @@ class ModelDeployer:
         if not compartment_id:
             compartment_id = OCIClientManager.default_compartment_id()
         if not compartment_id:
-            raise ValueError("Unable to determine compartment ID from environment. Please specify compartment_id.")
+            raise ValueError(
+                "Unable to determine compartment ID from environment. Please specify compartment_id."
+            )
 
         if isinstance(status, State):
             status = status.name
 
         if status is not None:
             kwargs["lifecycle_state"] = status
-        
+
         # https://oracle-cloud-infrastructure-python-sdk.readthedocs.io/en/latest/api/pagination.html#module-oci.pagination
         deployments = oci.pagination.list_call_get_all_results(
-            self.ds_client.list_model_deployments,
-            compartment_id, 
-            **kwargs
+            self.ds_client.list_model_deployments, compartment_id, **kwargs
         ).data
         return [ModelDeployment(deployment) for deployment in deployments]
 
-    def show_deployments(self, status = None, compartment_id=os.environ.get('NB_SESSION_COMPARTMENT_OCID', None)) -> pd.DataFrame:
-        """ Returns the model deployments associated with current compartment and data science client
+    def show_deployments(
+        self,
+        status=None,
+        compartment_id=os.environ.get("NB_SESSION_COMPARTMENT_OCID", None),
+    ) -> pd.DataFrame:
+        """Returns the model deployments associated with current compartment and data science client
             as a Dataframe that can be easily visualized
 
         Args:
             status ([str], optional): Status of deployment. Defaults to None.
-            compartment_id ([str], optional): Target compartment from which to list deployments. 
+            compartment_id ([str], optional): Target compartment from which to list deployments.
                                               Defaults to compartment set in the environment.
 
         Returns:
@@ -254,7 +300,9 @@ class ModelDeployer:
         display = pd.DataFrame()
         ids, urls, status_list = [], [], []
         for oci_model_deployment_object in model_deployments:
-            state_of_model = State._from_str(oci_model_deployment_object.lifecycle_state)
+            state_of_model = State._from_str(
+                oci_model_deployment_object.lifecycle_state
+            )
             if status == State.UNKNOWN or status.name == state_of_model.name:
                 model_dep_id = oci_model_deployment_object.id
                 model_dep_url = oci_model_deployment_object._model_deployment_url
@@ -262,7 +310,7 @@ class ModelDeployer:
                 ids.append(model_dep_id)
                 urls.append(model_dep_url)
                 status_list.append(model_dep_state)
-        display['model_id'] = ids
-        display['deployment_url'] = urls
-        display['current_state'] = status_list
-        return display
\ No newline at end of file
+        display["model_id"] = ids
+        display["deployment_url"] = urls
+        display["current_state"] = status_list
+        return display
