@@ -10,14 +10,11 @@ from typing import Union, List, Optional
 import collections
 import datetime
 import json
-import os
 import time
-from oci.auth import signers
 
 # Third party
 import pandas as pd
 import requests
-import yaml
 
 # Oracle
 from .common import utils
@@ -29,6 +26,7 @@ import oci
 DEFAULT_WAIT_TIME = 1200
 DEFAULT_POLL_INTERVAL = 30
 
+
 class ModelDeployment:
     """
     A class used to represent a Model Deployment.
@@ -63,9 +61,17 @@ class ModelDeployment:
 
     """
 
-    def __init__(self, properties=None, config=None, 
-                workflow_req_id=None, model_deployment_id=None, model_deployment_url="", 
-                ds_client=None, ds_composite_client=None, **kwargs):
+    def __init__(
+        self,
+        properties=None,
+        config=None,
+        workflow_req_id=None,
+        model_deployment_id=None,
+        model_deployment_url="",
+        ds_client=None,
+        ds_composite_client=None,
+        **kwargs,
+    ):
         """Creates a ModelDeployment object
 
         Args:
@@ -82,20 +88,31 @@ class ModelDeployment:
 
         if config is None:
             utils.get_logger().info("Using default configuration.")
-            
+
         if ds_client is None:
             ds_client = OCIClientManager.oci_ds_client(config)
         if ds_composite_client is None:
             ds_composite_client = OCIClientManager.oci_ds_composite_client(ds_client)
 
-        self.properties = properties if isinstance(properties, ModelDeploymentProperties) \
+        self.properties = (
+            properties
+            if isinstance(properties, ModelDeploymentProperties)
             else ModelDeploymentProperties(oci_model_deployment=properties, **kwargs)
+        )
 
-        self.current_state = State._from_str(
-            self.properties.lifecycle_state
-        ) if self.properties.lifecycle_state else State.UNKNOWN
-        self.url = model_deployment_url if model_deployment_url else self.properties.model_deployment_url
-        self.model_deployment_id = model_deployment_id if model_deployment_id else self.properties.id
+        self.current_state = (
+            State._from_str(self.properties.lifecycle_state)
+            if self.properties.lifecycle_state
+            else State.UNKNOWN
+        )
+        self.url = (
+            model_deployment_url
+            if model_deployment_url
+            else self.properties.model_deployment_url
+        )
+        self.model_deployment_id = (
+            model_deployment_id if model_deployment_id else self.properties.id
+        )
 
         self.workflow_state_progress = []
         self.workflow_steps = 5
@@ -109,12 +126,15 @@ class ModelDeployment:
         if self.ds_client:
             oci_config, signer = OCIClientManager.get_oci_config_signer(self.config)
             self.log_search_client = oci.loggingsearch.LogSearchClient(
-                oci_config,
-                signer=signer
+                oci_config, signer=signer
             )
 
-    def deploy(self, wait_for_completion:bool = True,
-            max_wait_time: int = DEFAULT_WAIT_TIME, poll_interval: int = DEFAULT_POLL_INTERVAL):
+    def deploy(
+        self,
+        wait_for_completion: bool = True,
+        max_wait_time: int = DEFAULT_WAIT_TIME,
+        poll_interval: int = DEFAULT_POLL_INTERVAL,
+    ):
         """deploy deploys the current ModelDeployment object
 
         Args:
@@ -133,10 +153,10 @@ class ModelDeployment:
         response = self.ds_composite_client.create_model_deployment_and_wait_for_state(
             self.properties.to_create_deployment()
         )
-        self.workflow_req_id = response.headers['opc-work-request-id']
+        self.workflow_req_id = response.headers["opc-work-request-id"]
         res_payload = json.loads(str(response.data))
-        self.current_state = State._from_str(res_payload['lifecycle_state'])
-        self.model_deployment_id = res_payload['id']
+        self.current_state = State._from_str(res_payload["lifecycle_state"])
+        self.model_deployment_id = res_payload["id"]
         if wait_for_completion:
             try:
                 self._wait_for_activation(max_wait_time, poll_interval)
@@ -145,13 +165,17 @@ class ModelDeployment:
                 raise e
         return self
 
-    def delete(self, wait_for_completion:bool = True, 
-            max_wait_time: int = DEFAULT_WAIT_TIME, poll_interval: int = DEFAULT_POLL_INTERVAL):
-        """" Deletes the current ModelDeployment object
+    def delete(
+        self,
+        wait_for_completion: bool = True,
+        max_wait_time: int = DEFAULT_WAIT_TIME,
+        poll_interval: int = DEFAULT_POLL_INTERVAL,
+    ):
+        """ " Deletes the current ModelDeployment object
 
         Args:
             wait_for_completion (bool, optional): Wait for deletion to complete. Defaults to True.
-            max_wait_time (int, optional): Maximum amount of time to wait in seconds (Defaults to 600). 
+            max_wait_time (int, optional): Maximum amount of time to wait in seconds (Defaults to 600).
                 Negative implies infinite wait time.
             poll_interval (int, optional): Poll interval in seconds (Defaults to 60).
 
@@ -163,10 +187,17 @@ class ModelDeployment:
 
         """
 
-        response = self.ds_composite_client.delete_model_deployment_and_wait_for_state(self.model_deployment_id)
-        self.workflow_req_id = response.headers['opc-work-request-id']
-        oci_model_deployment_object = self.ds_client.get_model_deployment(self.model_deployment_id).data
-        self.current_state = State._from_str(oci_model_deployment_object.lifecycle_state)
+        response = self.ds_composite_client.delete_model_deployment_and_wait_for_state(
+            self.model_deployment_id
+        )
+        # response.data from deleting model is None, headers are populated
+        self.workflow_req_id = response.headers["opc-work-request-id"]
+        oci_model_deployment_object = self.ds_client.get_model_deployment(
+            self.model_deployment_id
+        ).data
+        self.current_state = State._from_str(
+            oci_model_deployment_object.lifecycle_state
+        )
         if wait_for_completion:
             try:
                 self._wait_for_deletion(max_wait_time, poll_interval)
@@ -174,15 +205,21 @@ class ModelDeployment:
                 utils.get_logger().error(f"Error while trying to delete: {str(e)}")
                 raise e
         return self
-    
-    def update(self, properties: Union[ModelDeploymentProperties, dict, None] = None, wait_for_completion:bool = True,
-            max_wait_time: int = DEFAULT_WAIT_TIME, poll_interval: int = DEFAULT_POLL_INTERVAL, **kwargs):
-        """ Updates a model deployment
 
-        You can update `model_deployment_configuration_details` and change `instance_shape` and `model_id` 
-        when the model deployment is in the ACTIVE lifecycle state. 
-        The `bandwidth_mbps` or `instance_count` can only be updated while the model deployment is in the `INACTIVE` state. 
-        Changes to the `bandwidth_mbps` or `instance_count` will take effect the next time 
+    def update(
+        self,
+        properties: Union[ModelDeploymentProperties, dict, None] = None,
+        wait_for_completion: bool = True,
+        max_wait_time: int = DEFAULT_WAIT_TIME,
+        poll_interval: int = DEFAULT_POLL_INTERVAL,
+        **kwargs,
+    ):
+        """Updates a model deployment
+
+        You can update `model_deployment_configuration_details` and change `instance_shape` and `model_id`
+        when the model deployment is in the ACTIVE lifecycle state.
+        The `bandwidth_mbps` or `instance_count` can only be updated while the model deployment is in the `INACTIVE` state.
+        Changes to the `bandwidth_mbps` or `instance_count` will take effect the next time
         the `ActivateModelDeployment` action is invoked on the model deployment resource.
 
         Args:
@@ -199,45 +236,52 @@ class ModelDeployment:
             properties = ModelDeploymentProperties(properties, **kwargs)
 
         if wait_for_completion:
-            wait_for_states=["SUCCEEDED", "FAILED"]
+            wait_for_states = ["SUCCEEDED", "FAILED"]
         else:
             wait_for_states = []
 
         try:
-            response = self.ds_composite_client.update_model_deployment_and_wait_for_state(
-                self.model_deployment_id, 
-                properties.to_update_deployment(),
-                wait_for_states=wait_for_states,
-                waiter_kwargs={
-                    "max_interval_seconds": poll_interval,
-                    "max_wait_seconds": max_wait_time
-                }
+            response = (
+                self.ds_composite_client.update_model_deployment_and_wait_for_state(
+                    self.model_deployment_id,
+                    properties.to_update_deployment(),
+                    wait_for_states=wait_for_states,
+                    waiter_kwargs={
+                        "max_interval_seconds": poll_interval,
+                        "max_wait_seconds": max_wait_time,
+                    },
+                )
             )
-            if 'opc-work-request-id' in response.headers:
-                self.workflow_req_id = response.headers['opc-work-request-id']
+            if "opc-work-request-id" in response.headers:
+                self.workflow_req_id = response.headers["opc-work-request-id"]
             # Refresh the properties when model is active
             if wait_for_completion:
                 # # There is a small delay between update process finished and model becomes active
                 # self._wait_for_activation()
                 self.properties = ModelDeploymentProperties(
-                    oci_model_deployment=self.ds_client.get_model_deployment(self.model_deployment_id).data
+                    oci_model_deployment=self.ds_client.get_model_deployment(
+                        self.model_deployment_id
+                    ).data
                 )
             return self
         except Exception as e:
-            utils.get_logger().error("Updating model deployment failed with error: %s", format(e))
+            utils.get_logger().error(
+                "Updating model deployment failed with error: %s", format(e)
+            )
             raise e
-    
+
     @property
     def state(self) -> State:
-        """ Returns the deployment state of the current Model Deployment object
-        """
-        # Updates and returns self.state 
-        oci_state = self.ds_client.get_model_deployment(self.model_deployment_id).data.lifecycle_state
+        """Returns the deployment state of the current Model Deployment object"""
+        # Updates and returns self.state
+        oci_state = self.ds_client.get_model_deployment(
+            self.model_deployment_id
+        ).data.lifecycle_state
         self.current_state = State._from_str(oci_state)
         return self.current_state
 
     def list_workflow_logs(self) -> list:
-        """ Returns a list of the steps involved in deploying a model
+        """Returns a list of the steps involved in deploying a model
 
         Returns:
             [list]: List of dictionaries detailing the status of each step in the deployment process
@@ -250,14 +294,14 @@ class ModelDeployment:
             utils.get_logger().info("Workflow req id not available")
             raise Exception
         return self.ds_client.list_work_request_logs(self.workflow_req_id).data
-    
-    def predict(self, json_input:json) -> json:
-        """ Returns prediction of input data run against the model deployment endpoint
+
+    def predict(self, json_input: json) -> json:
+        """Returns prediction of input data run against the model deployment endpoint
 
         Args:
             json_input (JSON): [description]
             auth (str, optional): Authentication mode. Defaults to 'api_keys'.
-        
+
         Returns:
             dict: Prediction
 
@@ -266,10 +310,16 @@ class ModelDeployment:
         """
         endpoint = self.url
         _, signer = OCIClientManager().get_oci_config_signer(self.config)
-        response = requests.post(f"{endpoint}/predict", json=json_input, auth=signer).json()
+        response = requests.post(
+            f"{endpoint}/predict", json=json_input, auth=signer
+        ).json()
         return response
-    
-    def _wait_for_deletion(self, max_wait_time: int = DEFAULT_WAIT_TIME, poll_interval: int = DEFAULT_POLL_INTERVAL):
+
+    def _wait_for_deletion(
+        self,
+        max_wait_time: int = DEFAULT_WAIT_TIME,
+        poll_interval: int = DEFAULT_POLL_INTERVAL,
+    ):
         """_wait_for_deletion blocks until deletion is complete
 
         Args:
@@ -281,34 +331,52 @@ class ModelDeployment:
 
         Raises:
             Exception: If during the time window when the current state is not DELETED a check on the current
-                state returns FAILED or INACTIVE, raise an Exception 
+                state returns FAILED or INACTIVE, raise an Exception
         """
 
         start_time = time.time()
         prev_message = ""
-        if (max_wait_time > 0 and utils.seconds_since(start_time) >= max_wait_time):
+        if max_wait_time > 0 and utils.seconds_since(start_time) >= max_wait_time:
             utils.get_logger().error(f"Error: Max wait time exceeded")
-        while (max_wait_time < 0 or utils.seconds_since(start_time) < max_wait_time) and self.current_state.name.upper() != "DELETED":
+        while (
+            max_wait_time < 0 or utils.seconds_since(start_time) < max_wait_time
+        ) and self.current_state.name.upper() != "DELETED":
             if self.current_state.name.upper() == State.FAILED.name:
-                utils.get_logger().info("Deletion Failed. Please use Deployment ID for further steps.")
+                utils.get_logger().info(
+                    "Deletion Failed. Please use Deployment ID for further steps."
+                )
                 break
             if self.current_state.name.upper() == State.INACTIVE.name:
                 utils.get_logger().info("Deployment Inactive")
                 break
             prev_state = self.current_state.name
-            model_deployment_payload = json.loads(str(self.ds_client.get_model_deployment(self.model_deployment_id).data))
-            self.current_state = State._from_str(model_deployment_payload['lifecycle_state']) if 'lifecycle_state' in model_deployment_payload else State.UNKNOWN
-            workflow_payload = self.ds_client.list_work_request_logs(self.workflow_req_id).data
+            model_deployment_payload = json.loads(
+                str(self.ds_client.get_model_deployment(self.model_deployment_id).data)
+            )
+            self.current_state = (
+                State._from_str(model_deployment_payload["lifecycle_state"])
+                if "lifecycle_state" in model_deployment_payload
+                else State.UNKNOWN
+            )
+            workflow_payload = self.ds_client.list_work_request_logs(
+                self.workflow_req_id
+            ).data
             if isinstance(workflow_payload, list) and len(workflow_payload) > 0:
                 if prev_message != workflow_payload[-1].message:
                     prev_message = workflow_payload[-1].message
             if prev_state != self.current_state.name:
-                if 'model_deployment_url' in model_deployment_payload:
-                    self.url = model_deployment_payload['model_deployment_url']
-                utils.get_logger().info(f"Status Update: {self.current_state.name} in {utils.seconds_since(start_time)} seconds")
+                if "model_deployment_url" in model_deployment_payload:
+                    self.url = model_deployment_payload["model_deployment_url"]
+                utils.get_logger().info(
+                    f"Status Update: {self.current_state.name} in {utils.seconds_since(start_time)} seconds"
+                )
             time.sleep(poll_interval)
 
-    def _wait_for_activation(self, max_wait_time: int = DEFAULT_WAIT_TIME, poll_interval: int = DEFAULT_POLL_INTERVAL):
+    def _wait_for_activation(
+        self,
+        max_wait_time: int = DEFAULT_WAIT_TIME,
+        poll_interval: int = DEFAULT_POLL_INTERVAL,
+    ):
         """_wait_for_activation blocks deployment until activation is complete
 
         Args:
@@ -323,19 +391,35 @@ class ModelDeployment:
         prev_message = ""
         prev_workflow_stage_len = 0
         with utils.get_progress_bar(self.workflow_steps) as progress:
-            if (max_wait_time > 0 and utils.seconds_since(start_time) >= max_wait_time):
+            if max_wait_time > 0 and utils.seconds_since(start_time) >= max_wait_time:
                 utils.get_logger().error(f"Error: Max wait time exceeded")
-            while (max_wait_time < 0 or utils.seconds_since(start_time) < max_wait_time) and self.current_state.name.upper() != "ACTIVE":
+            while (
+                max_wait_time < 0 or utils.seconds_since(start_time) < max_wait_time
+            ) and self.current_state.name.upper() != "ACTIVE":
                 if self.current_state.name.upper() == State.FAILED.name:
-                    utils.get_logger().info("Deployment Failed. Please use Deployment ID for further steps.")
+                    utils.get_logger().info(
+                        "Deployment Failed. Please use Deployment ID for further steps."
+                    )
                     break
                 if self.current_state.name.upper() == State.INACTIVE.name:
                     utils.get_logger().info("Deployment Inactive")
                     break
                 prev_state = self.current_state.name
-                model_deployment_payload = json.loads(str(self.ds_client.get_model_deployment(self.model_deployment_id).data))
-                self.current_state = State._from_str(model_deployment_payload['lifecycle_state']) if 'lifecycle_state' in model_deployment_payload else State.UNKNOWN
-                workflow_payload = self.ds_client.list_work_request_logs(self.workflow_req_id).data
+                model_deployment_payload = json.loads(
+                    str(
+                        self.ds_client.get_model_deployment(
+                            self.model_deployment_id
+                        ).data
+                    )
+                )
+                self.current_state = (
+                    State._from_str(model_deployment_payload["lifecycle_state"])
+                    if "lifecycle_state" in model_deployment_payload
+                    else State.UNKNOWN
+                )
+                workflow_payload = self.ds_client.list_work_request_logs(
+                    self.workflow_req_id
+                ).data
                 if isinstance(workflow_payload, list) and len(workflow_payload) > 0:
                     if prev_message != workflow_payload[-1].message:
                         for _ in range(len(workflow_payload) - prev_workflow_stage_len):
@@ -344,15 +428,16 @@ class ModelDeployment:
                         prev_message = workflow_payload[-1].message
                         prev_workflow_stage_len = len(workflow_payload)
                 if prev_state != self.current_state.name:
-                    if 'model_deployment_url' in model_deployment_payload:
-                        self.url = model_deployment_payload['model_deployment_url']
-                    utils.get_logger().info(f"Status Update: {self.current_state.name} in {utils.seconds_since(start_time)} seconds")
+                    if "model_deployment_url" in model_deployment_payload:
+                        self.url = model_deployment_payload["model_deployment_url"]
+                    utils.get_logger().info(
+                        f"Status Update: {self.current_state.name} in {utils.seconds_since(start_time)} seconds"
+                    )
                 time.sleep(poll_interval)
 
     @staticmethod
     def format_datetime(dt: datetime.datetime) -> str:
-        """Converts datetime object to RFC3339 date time format in string
-        """
+        """Converts datetime object to RFC3339 date time format in string"""
         return dt.isoformat()[:-3] + "Z"
 
     def logs(self, time_start=None, time_end=None, limit=100, log_type="access"):
@@ -379,9 +464,13 @@ class ModelDeployment:
                 "Log search is not available. "
                 "It is recommended that you initialize a ModelDeployment object using a DataScienceClient instance."
             )
-        if not self.properties.category_log_details or not getattr(self.properties.category_log_details, log_type):
-            raise AttributeError(f"Deployment {self.model_deployment_id} has no {log_type} log configuration.")
-        
+        if not self.properties.category_log_details or not getattr(
+            self.properties.category_log_details, log_type
+        ):
+            raise AttributeError(
+                f"Deployment {self.model_deployment_id} has no {log_type} log configuration."
+            )
+
         # Default time_start and time_end
         if time_start is None:
             time_start = datetime.datetime.utcnow() - datetime.timedelta(days=14)
@@ -405,10 +494,12 @@ class ModelDeployment:
             # Single quotes must be used for the string in <where_expression>
             # source = <OCID> is not allowed but source = *<OCID> works
             search_query=f'SEARCH "{self.properties.compartment_id}/{log_details.log_group_id}/{log_details.log_id}" '
-                f'| WHERE source = \'*{self.model_deployment_id}\'',
+            f"| WHERE source = '*{self.model_deployment_id}'",
             # is_return_field_info=True
         )
-        return self.log_search_client.search_logs(search_details, limit=limit).data.results
+        return self.log_search_client.search_logs(
+            search_details, limit=limit
+        ).data.results
 
     def show_logs(self, time_start=None, time_end=None, limit=100, log_type="access"):
         """Shows deployment logs as a pandas dataframe
@@ -425,17 +516,24 @@ class ModelDeployment:
             a pandas DataFrame containing logs.
 
         """
-        def prepare_log_record(log):
-            """Converts a log record to ordered dict
-            """
-            return collections.OrderedDict([
-                ("id", log.get("id")),
-                ("time", log.get("time")),
-                ("message", log.get("logContent", {}).get("data", {}).get("message")),
-                ("subject", log.get("subject")),
-                ("source", log.get("source"))
-            ])
 
-        logs = self.logs(time_start=time_start, time_end=time_end, limit=limit, log_type=log_type)
+        def prepare_log_record(log):
+            """Converts a log record to ordered dict"""
+            return collections.OrderedDict(
+                [
+                    ("id", log.get("id")),
+                    ("time", log.get("time")),
+                    (
+                        "message",
+                        log.get("logContent", {}).get("data", {}).get("message"),
+                    ),
+                    ("subject", log.get("subject")),
+                    ("source", log.get("source")),
+                ]
+            )
+
+        logs = self.logs(
+            time_start=time_start, time_end=time_end, limit=limit, log_type=log_type
+        )
         # log data are stored in the data attribute of oci.loggingsearch.models.SearchResult
         return pd.DataFrame([prepare_log_record(log.data) for log in logs])
