@@ -16,18 +16,20 @@ def experimental(cls):
     @functools.wraps(cls)
     def wrapper(*args, **kwargs):
         instance = cls(*args, **kwargs)
-        print(f'{cls.__name__} is experimental and may be removed in the future.')
+        print(f"{cls.__name__} is experimental and may be removed in the future.")
         return instance
+
     return wrapper
 
 
 class PY4JGateway:
-
     def __init__(self) -> None:
         from py4j.java_gateway import GatewayParameters, JavaGateway, launch_gateway
         port = launch_gateway(
-            java_path='/usr/bin/java',
-            classpath=os.path.join(os.environ.get('CONDA_PREFIX'), 'text-extraction-tools.jar'),
+            java_path="/usr/bin/java",
+            classpath=os.path.join(
+                os.environ.get("CONDA_PREFIX"), "text-extraction-tools.jar"
+            ),
         )
         self.gateway = JavaGateway(gateway_parameters=GatewayParameters(port=port))
 
