@@ -11,25 +11,31 @@ import pandas as pd
 
 from ads.type_discovery import logger
 from ads.type_discovery.abstract_detector import AbstractTypeDiscoveryDetector
-from ads.type_discovery.typed_feature import UnknownTypedFeature, CategoricalTypedFeature
+from ads.type_discovery.typed_feature import (
+    UnknownTypedFeature,
+    CategoricalTypedFeature,
+)
 
 
 class UnknownDetector(AbstractTypeDiscoveryDetector):
-
     def discover(self, name, series):
         candidate = series.loc[~series.isnull()].iloc[0]
 
-        if series.dtype == 'object':
+        if series.dtype == "object":
             #
             # if we got all through all the other detectors and it's a string type of feature then we
             # just call it a high dimensional categorical
             #
             return CategoricalTypedFeature.build(name, series)
         else:
-            logger.debug("type discovery on column [{}]/[{}] result is Unknown".format(name, series.dtype))
+            logger.debug(
+                "type discovery on column [{}]/[{}] result is Unknown".format(
+                    name, series.dtype
+                )
+            )
             return UnknownTypedFeature.build(name, series)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     dd = UnknownDetector()
     print(dd.discover("unknown", pd.Series([None, "94065", "90210", None])))
